@@ -10,8 +10,6 @@ CREATE TABLE sbc_vpns (id INTEGER PRIMARY KEY, iprange VARCHAR(15) NOT NULL DEFA
 INSERT INTO key_val VALUES ('is_sbc_vm', '1');
 INSERT into key_val VALUES ('syslog_facility', '16');
 INSERT into key_val VALUES ('logcdr', '1');
-INSERT into key_val VALUES ('cloudAddress', 'berocloud.beronet.com');
-INSERT into key_val VALUES ('cloud_show_status','1');
 INSERT into key_val VALUES ('sip_transport_lan', 'tcp:udp');
 INSERT into key_val VALUES ('sip_transport_wan', 'tcp:udp');
 INSERT into key_val VALUES ('stack_active_wan', '1');
@@ -27,3 +25,5 @@ INSERT into key_val VALUES ('rtpports_wan', '6000-7000');
 INSERT into key_val VALUES ('sip_bindport_wan', '5060');
 INSERT into key_val VALUES ('activate', '0');
 INSERT into key_val VALUES ('master', '0');
+INSERT into key_val VALUES ('sip_useragent_lan', 'Cloud SBC v{FIRMWARE}');
+INSERT into key_val VALUES ('sip_useragent_wan', 'Cloud SBC');
