@@ -3,9 +3,110 @@
 require_once('/usr/fallback/beroConf.php');
 include_once("/usr/www/include/SQLite2ToSQLite3.php");
 
-// TODO: using GUI-Class would avoid to check if the class exists
-if (!class_exists('beroAri')) {
-	require_once('/usr/local/www/berogui/misc/database.php');
+defined('_BEROARI_CLASS') or require('/usr/local/www/berogui/misc/database.php');
+
+// normal behavior. aka, FW >= 21.03 on normal/update mode
+if (file_exists('/usr/php/include/rootHelper.class.php')) {
+	require_once('/usr/php/include/rootHelper.class.php');
+}
+// specific behavior. aka, FW installation from FW < 21.03 to FW >= 21.03
+// so we use the file which gonna be installed on the next reboot
+else if (file_exists('/home/admin/conf/rootfs/pkg/rootfs/usr/php/include/rootHelper.class.php')) {
+	require_once('/home/admin/conf/rootfs/pkg/rootfs/usr/php/include/rootHelper.class.php');
+}
+// an installation process failed. we defined a dummy rootHelper class to avoid PHP errors
+else {
+	### BACKUP CLASS ###
+	### PLEASE DO NOT USE IT, USE rootHelper instead
+	class rootHelper {
+		public static function convertSecondsToDaily($s) {
+			return('');
+		}
+		public static function getDate() {
+			return('');
+		}
+		public static function exec($is_sbc_vm, $cmd) {
+			return(exec($cmd));
+		}
+		public static function getAppFsVersion() {
+			return('');
+		}
+		public static function getFpgaVersion() {
+			return('');
+		}
+		public static function getLif() {
+			return(array());
+		}
+		public static function getLifCount() {
+			return(0);
+		}
+		public static function getMtdblock() {
+			return('');
+		}
+		public static function getNetworkGateway($Iface, $is_sbc_vm = 0) {
+			return(exec('/usr/bin/expr match "$(/sbin/route -n | grep '. $Iface .' | grep UG)" "0.0.0.0 *\([0-9\.]*\)"'));
+		}
+		public static function getNetworkIfaceByName($Iface, $bc) {
+			return(@file_get_contents('/sys/class/beronet/gateway/li_count') == 3 ? 'eth0.10' : 'eth0');
+		}
+		public static function getNetworkInfo() {
+			return('');
+		}
+		public static function getNetworkIpAddr() {
+			return('');
+		}
+		public static function getNetworkMask() {
+			return('');
+		}
+		public static function getNetworkMacAddr() {
+			return('');
+		}
+		public static function getNetworkNameserver() {
+			$info = array();
+			foreach (file('/etc/resolv.conf') as $line) {
+				if (strstr($line, 'nameserver')) {
+					$info[] = end(explode(" ", $line));
+				}
+			}
+			return($info);
+		}
+		public static function getOpensslVersion() {
+			return('');
+		}
+		public static function getPackageInformation() {
+			return('');
+		}
+		public static function getPhpVersion() {
+			return(PHP_VERSION);
+		}
+		public static function getResetJumper() {
+			return(0);
+		}
+		public static function getRevision() {
+			return('');
+		}
+		public static function getRootFsVersion() {
+			return('');
+		}
+		public static function getSerial() {
+			return(trim(@file_get_contents('/sys/class/beronet/gateway/serial')));
+		}
+		public static function getStorage() {
+			return(array());
+		}
+		public static function getType() {
+			return('');
+		}
+		public static function getUptime() {
+			return('');
+		}
+		public static function reboot() {
+		
+			return( exec('/usr/local/init/rcK') && 
+				exec('echo -ne 1 > /sys/class/beronet/fpga/reset') &&
+				exec('/sbin/reboot'));
+		}
+	}
 }
 
 /**
@@ -13,167 +114,7 @@ if (!class_exists('beroAri')) {
  * @author Miguel Palmer <mp@beronet.com>
  * @author Florian Kraatz <fk@beronet.com>
  */
-class Helper {
-
-	/**
-	 * Gateway neustarten
-	 */
-	public static function reboot($url, $apicall=false) {
-		/* rck wird ausgeführt, wenn rck nach 10 Sekunden
-		 * nicht richtig beendet wurde, wird rcK gestoppt und die Karte wird
-		 * neugestartet. Per AJAX wird geprüft ob die Karte wieder UP ist, die
-		 * Loginseite wird dann wieder angezeigt.
-		 */
-		$handle = popen('/bin/sh /etc/init.d/rcK', 'r');
-		$i = 0;
-		while (!feof($handle) && $i++ != 10) {
-			sleep(1);
-		}
-		pclose($handle);
-		if (!$apicall) {
-			print("<script type='text/javascript'>
-				window.setTimeout('setRequest()',7000);
-		                </script>");
-			flush();
-		}
-		exec('/usr/bin/killall rcK');
-		`/sbin/reboot -d5 >> /dev/null &`;
-	}
-
-	/**
-	 *  Funktion für das Löschen eines Moduls und der entsprechenden Dialplaneinträge,
-	 * wenn die Belegung der Line Interfaces sich ändert
-	 */
-	public static function deleteModul($li, $name, $table) {
-			// FUNCTION NEVER USED. SHOULD BE REMODED \\
-		$ba = new beroAri();
-
-
-		//CAS channels und Dialplan Einträge löschen löschen.
-		if ($table == "cas") {
-			$query = $ba->select("select port from $table where lif='" . sqlite_escape_string($li) . "' and type='" . sqlite_escape_string($name) . "'");
-			while ($entry = $ba->fetch_array($query)) {
-				$query = $ba->select("select * from cas_channels where port='" . $entry['port'] . "'");
-				while ($ent = $ba->fetch_array($query)) {
-					$ba->delete("delete from dialplan where fromDirection='" . sqlite_escape_string($table) . "' and fromId='g:" . $ent['gr'] . "'");
-					$ba->delete("delete from dialplan where fromDirection='" . sqlite_escape_string($table) . "' and fromId='" . $ent['channel'] . "'");
-					$ba->delete("delete from dialplan where toDirection='" . sqlite_escape_string($table) . "' and toId='g:" . $ent['gr'] . "'");
-					$ba->delete("delete from dialplan where toDirection='" . sqlite_escape_string($table) . "' and toId='" . $ent['channel'] . "'");
-				}
-				$ba->delete("delete from cas_channels where port='" . $entry["port"] . "'");
-			}
-			//Dialplan Einträge aller anderen Technologien löschen
-		} else {
-			$query = $ba->select("select * from " . sqlite_escape_string($table) . " where lif='" . sqlite_escape_string($li) . "' and type='" . sqlite_escape_string($name) . "'");
-			while ($entry = $ba->fetch_array($query)) {
-				$ba->delete("delete from dialplan where fromDirection='$table' and fromId='g:" . $entry['gr'] . "'");
-				$ba->delete("delete from dialplan where fromDirection='$table' and fromId='" . $entry['port'] . "'");
-				$ba->delete("delete from dialplan where toDirection='$table' and toId='g:" . $entry['gr'] . "'");
-				$ba->delete("delete from dialplan where toDirection='$table' and toId='" . $entry['port'] . "'");
-			}
-		}
-		$ba->delete("delete from " . sqlite_escape_string($table) . " where lif='" . sqlite_escape_string($li) . "' and type='" . sqlite_escape_string($name) . "'");
-
-
-		$ba->set('portswitch', 0);
-
-		$q = $ba->select("SELECT type, lif FROM isdn union SELECT type, lif FROM analog union SELECT type, lif FROM gsm order by lif");
-		$i = 0;
-		while ($ent = $ba->fetch_array($q)) {
-			$lif[$i] = $ent['lif'];
-			$type[$i] = $ent['type'];
-			$i++;
-		}
-
-		$revision = self::getRevision();
-		if (($type[0] == "bf4S0" || $type[0] == "bf2S02FXS" || $type[0] == "bf4FXS" || $type[0] == "bf4FXO") && !isset($type[1]) && $revision != "1.80" && $revision != "1.8") {
-			$ba->set('portswitch', 1);
-		}
-
-		$option = $ba->get("activate");
-		if ($option <= 3)
-			$query = $ba->set('activate', '3');
-		echo "<script>aktivieren(1,'state','3','" . ACTIVATE . "');</script>";
-	}
-
-	/**
-	 * Funktion für das Löschen von Call progress tablea,
-	 * wenn die Belegung der Line Interfaces sich ändert
-	 */
-	public static function deleteCPT($dir) {
-		//echo $li.$name.$table;
-		$ba = new beroAri();
-		$query = $ba->select("select * from callprogress where direction='" . sqlite_escape_string($dir) . "'");
-		while ($entry = $ba->fetch_array($query)) {
-			$ba->delete("delete from callprogress_entries where id_name='" . $entry['id'] . "'");
-		}
-		$ba->delete("delete from callprogress where direction='" . sqlite_escape_string($dir) . "'");
-	}
-
-	/**
-	 *  Fügt in die Datenbank ein neues Modul hinzu
-	 */
-	public static function createModul($setPortSwitch = false) {
-
-		$ba = new beroAri();
-
-		if ($setPortSwitch == true)
-			$ba->set("portswitch", 0);
-		$queries_li1 = $ba->add_module_db(1, 0, 0);
-
-		if (!empty($queries_li1)) {
-			foreach ($queries_li1 as $query) {
-				$ba->exec_query($query);
-			}
-			unset($queries_li1);
-		}
-
-		if ($ba->is_error()) {
-			echo '<script>alert(\'' . $ba->error() . '\');</script>';
-		}
-
-		$option = $ba->get("activate");
-		if ($option <= 3)
-			$query = $ba->set('activate', '3');
-	}
-
-	public static function getIsdnPorts() {
-		//TODO: optimize this function and move it to HelperPstn
-		//Ein neues Datenbankobjekt wird erzeugt.
-		$ba = new beroAri();
-		//ISDN Ports suchen
-		$qu = $ba->select("select port from isdn");
-		$result = array();
-		while ($entry = $ba->fetch_array($qu)) {
-			array_push($result, $entry['port']);
-		}
-		return $result;
-	}
-
-	/**
-	 * Generiert ein Array mit den neuesten verfügbaren Software Versionen
-	 */
-	public static function getAvailableFwVersion() {
-
-		$url = 'ftp://appliance.beronet.com/beronet_gateway/firmware_3LI.list';
-
-		if (!($lines = @file($url))) {
-			return(false);
-		}
-
-		foreach ($lines as $line) {
-			if (($line == "\n") || ($line[0] == '#')) {
-				continue;
-			}
-
-			$tmp = explode(';', trim($line, "\n\t"));
-
-			$ret[] = array('name' => $tmp[0]);
-			break;
-		}
-
-		return($ret);
-	}
+class Helper extends rootHelper {
 
 	public static function getTimezoneList() {
 		$timezones = array(
@@ -444,9 +385,10 @@ class Helper {
 			unlink ("/usr/conf/need_red_activate");
 		}
 		
-		// check graceful_activate
+		// when graceful is active, don't show if lower than graceful
 		$graceful = $ba->get('graceful_action');
-		if ($option <= $graceful) {
+		$gracefulcron = preg_match('/graceful-action.sh/', file_get_contents('/usr/conf/cron/root'));
+		if ($option <= $graceful && $gracefulcron) {
 			return;
 		}
 
@@ -475,45 +417,6 @@ class Helper {
 		return $ba->get("activate");
 	}
 
-	/**
-	 * @return int Anzahl an Line interfaces
-	 */
-	public static function getLifCount() {
-		if (file_exists('/sys/class/beronet/gateway/li_count')) {
-			return(trim(file_get_contents('/sys/class/beronet/gateway/li_count')));
-		}
-		return null;
-	}
-
-	/**
-	 * Gibt den Namen des angefragen Line interfaces zurück
-	 * @param int $LifIndex
-	 * @return string
-	 */
-	public static function getLifName($LifIndex) {
-		return(file_exists(self::getLifPath() . 'li' . $LifIndex . '/module') ? trim(@file_get_contents(self::getLifPath() . 'li' . $LifIndex . '/module')) : 'none');
-	}
-
-	/**
-	 * Gibt den Namen aller Line interfaces zurück
-	 * @return array
-	 */
-	public static function getLif() {
-		$li = array();
-		for ($i = 0; $i < self::getLifCount(); $i++) {
-			$li[$i] = self::getLifName($i);
-		}
-		return($li);
-	}
-
-	/**
-	 * Gibt einen Pfad zurück
-	 * @return string
-	 */
-	public static function getLifPath() {
-		return (is_dir('/usr/conf/lif')) ? '/usr/conf/lif/' : '/sys/class/beronet/';
-	}
-
 	/**
 	 * Return the specific FXO country setting for the given country $c
 	 * @param string $c
@@ -599,84 +502,32 @@ class Helper {
 		return $country[$c];
 	}
 
-	public static function getRevision() {
-		return self::_getRevision();
-	}
-
-	public static function getDate() {
-		return self::_getDate();
-	}
-
-	public static function getSerial($is_sbc_vm = '0') {
-		$function_list = array(
-			'0' => '_getSbcSerial',
-			'1' => '_getSbcvmSerial',
-		);
-		$function = $function_list[$is_sbc_vm == 1 ? '1' : '0'];
-		return self::$function();
-	}
-
-	public function getFpgaVersion() {
-		return self::_getFpgaVersion();
-	}
-
 	public static function getDateByFormat($formatString = null) {
 		@exec('/bin/date ' . (($formatString != null) ? $formatString : '-R'), $output);
 		return(trim($output[0]));
 	}
 
-	public static function convertSecondsToDaily($seconds) {
-		if ((int)$seconds <= 0) {
-			return array('d' => 0, 'h' => 0, 'm' => 0, 's' => 0);
-		}
-		$num = floatval($seconds);
-
-		$secs = (int)fmod($num, 60);
-
-		$num = (int)($num / 60);
-		$mins = $num % 60;
-
-		$num = (int)($num / 60);
-		$hours = $num % 24;
-
-		$days = (int)($num / 24);
-
-		return array('d' => $days, 'h' => $hours, 'm' => $mins, 's' => $secs);
-	}
-
-	public static function getInfo($bc = null, $ba = null, $isgw = null, $type = 0) {
+	public static function getInfo($bc = null, $ba = null, $isgw = null) {
 		// default
-		$info_general = array(
-			'date'				=> '_getDate', 
-			'isgw_uptime'	=> '_getIsgwUptime',
-			'openssl'			=> '_getOpensslVersion',
-			'php' 				=> '_getPhpVersion',
-			's2s_licenses'=> '_getSip2SipLicences',
-		);
-
-		$info_by_type = array(
-			// sbc
-			'0' => array(
-				'appfs' 				=> '_getAppFsVersion',
-				'fgpa'					=> '_getFpgaVersion',
-				'hw_revision'		=> '_getRevision',
-				'lif'						=> '_getLifInfo',
-				'msp_fw'				=> '_getMspFirmwareVersion', 
-				'mtdblock'			=> '_getMtdblock',
-				'network'				=> '_getSbcNetworkInfo',
-				'rootfs'				=> '_getRootFsVersion',
-				'serial'				=> '_getSbcSerial',
-				'storage'				=> '_getSbcStorage',
-				'system_uptime' => '_getSbcUptime',
-			),
-			// sbcvm
-			'1' => array(
-				'network'				=> '_getSbcvmNetworkInfo',
-				'package'				=> '_getPackageInformation',
-				'serial'				=> '_getSbcvmSerial',
-				'system_uptime' => '_getSbcvmUptime',
-				'vpn-client'		=> '_getSbcvmVpnClient',
-			),
+		$infos = array(
+			'appfs' 				=> 'getAppFsVersion',
+			'date'					=> 'getDate', 
+			'fpga'					=> 'getFpgaVersion',
+			'hw_revision'		=> 'getRevision',
+			'isgw_uptime'		=> 'getIsgwUptime',
+			'lif'						=> 'getLifInfo',
+			'msp_fw'				=> 'getMspFirmwareVersion', 
+			'mtdblock'			=> 'getMtdblock',
+			'network'				=> 'getNetworkInfo',
+			'openssl'				=> 'getOpensslVersion',
+			'package'				=> 'getPackageInformation',
+			'php' 					=> 'getPhpVersion',
+			'rootfs'				=> 'getRootFsVersion',
+			'serial'				=> 'getSerial',
+			'storage'				=> 'getStorage',
+			'system_uptime' => 'getUptime',
+			's2s_licenses'	=> 'getSip2SipLicences',
+			'vpn-client'		=> 'getVpnClient',
 		);
 
 		if (is_null($bc)) {
@@ -684,55 +535,46 @@ class Helper {
 			$bc = new beroConf('root');
 		}
 
-		if (is_null($ba)) {
+		if (is_null($ba) && file_exists('/usr/local/www/berogui/misc/database.php')) {
 			require_once('/usr/local/www/berogui/misc/database.php');
 			$ba = new beroAri();
 		}
 
 		// login to isgw
-		if (is_null($isgw)) {
+		if (is_null($isgw) && file_exists('/usr/local/www/berogui/includes/isgwtelnet.php')) {
 			require_once('/usr/local/www/berogui/includes/isgwtelnet.php');
 			$isgw = new isgwtelnet();
 			$isgw->isgw_login();
 		}
 
 		// get the info
-		$info_by_type = array_merge($info_by_type[$type], $info_general);
-		foreach ($info_by_type as $key => $function) {
-			$info[$key] = self::$function($bc, $ba, $isgw);
+		foreach ($infos as $key => $function) {
+			$value = self::$function($bc->get('root', 'is-sbc-vm') == 1, $bc, $ba, $isgw);
+			if (!is_null($value)) {
+				$info[$key] = $value;
+			}
 		}
 
 		return $info;
 	}
-	
-	/* [PRIVATE METHODS TO getInfo PUBLIC METHOD */
-	private static function _getAppFsVersion($bc = null, $ba = null, $isgw = null) {
-		if (is_null($bc)) {
-			$bc = new beroConf('root');
+
+	public static function getIsgwUptime($is_sbc_vm = 0, $bc = null, $ba = null, $isgw = null) {
+		if (is_null($isgw)) {
+			return(null);
 		}
-		preg_match('/appfs-(.*).tar.gz/', $bc->get('root', 'app-image'), $matches);
-		return($matches[1]);
-	}
-
-	private static function _getDate($bc = null, $ba = null, $isgw = null) {
-		@exec('/bin/date -R', $output);
-		return(trim($output[0]));
-	}
-
-	private static function _getFpgaVersion($bc = null, $ba = null, $isgw = null) {
-		return(trim(file_get_contents('/sys/class/beronet/fpga/version')));
-	}
-
-	private static function _getIsgwUptime($bc, $ba, $isgw) {
 		$isgw_uptime = $isgw->isgw_uptime();
 		$isgw_uptime = preg_split("/: /", $isgw_uptime);
 		$isgw_uptime = explode(':', $isgw_uptime[1]);
 		$isgw_uptime = 3600*$isgw_uptime[0] + 60*$isgw_uptime[1] + $isgw_uptime[2];
 		$isgw_uptime = self::convertSecondsToDaily($isgw_uptime);
-		return "{$isgw_uptime['d']}d:{$isgw_uptime['h']}h:{$isgw_uptime['m']}m:{$isgw_uptime['s']}s";
+		return("{$isgw_uptime['d']}d:{$isgw_uptime['h']}h:{$isgw_uptime['m']}m:{$isgw_uptime['s']}s");
 	}
 
-	private static function _getLifInfo($bc, $ba, $isgw = null) {
+	public static function getLifInfo($is_sbc_vm = 0, $bc = null, $ba = null, $isgw = null) {
+		// cloud sbc + std sbc in recovery mode
+		if ($is_sbc_vm || is_null($ba)) {
+			return(null);
+		}
 		$info = array();
 		for ($i = 0; $i < self::getLifCount(); $i++) {
 			$query = $ba->select('SELECT type FROM isdn WHERE lif="' . $i . '" union ' .
@@ -745,294 +587,51 @@ class Helper {
 				$info[$i] = 'li' . $i . ':  ' . $type;
 			}
 		}
-		return $info;
-	}
-
-	private static function _getMtdblock($bc = null, $ba = null, $isgw = null) {
-		$php_vers_exploded = explode('.', PHP_VERSION);
-            	return $php_vers_exploded[0] < '7' ? '5' : '7';
-	}
-
-	private static function _getMspFirmwareVersion($bc, $ba, $isgw) {
-		$msp = explode(':', $isgw->Query('fw'));
-		return $msp[1];
-	}
-
-	private static function _getPackageInformation ($bc = null, $ba = null, $isgw = null, $file = '/usr/local/VERSION') {
-		if (file_exists($file)) {
-			extract(parse_ini_file($file));
-			return array(
-				'appfs'		=> $APPFS,
-				'beronode'=> $BERONODE,
-				'version' => $VERSION,
-			);
-		}
-		return 'unknown (error)';
-	}
-
-	private static function _getOpensslVersion($bc, $ba = null, $isgw = null) {
-		$is_sbc_vm = $bc->get('root', 'is-sbc-vm') == 1 ? 1 : 0;
-		$cmd = array(
-			0	=> "/usr/local/bin/openssl version",
-			1 => "/usr/bin/openssl version",
-		);
-		$version = self::exec($is_sbc_vm, $cmd[$is_sbc_vm]);
-		if (preg_match('/OpenSSL ([0-9.a-z]+) .*/', $version, $version_matched)) {
-			return $version_matched[1];
-		}	
-		// default
-		return '1.0.2u (default)';
-	}
-
-	private static function _getPhpVersion($bc = null, $ba = null, $isgw = null) {
-		return PHP_VERSION;
-	}
-
-	private static function _getRevision($bc = null, $ba = null, $isgw = null) {
-		if (file_exists('/sys/class/beronet/gateway/revision')) {
-			return(trim(file_get_contents('/sys/class/beronet/gateway/revision')));
-		}
-		return null;
-	}
-
-	private static function _getRootFsVersion($bc = null, $ba = null, $isgw = null) {
-		$f = @file('/pkginfo/VERSION.rootfs');
-		$tmp = explode('=', $f[1]);
-		return(trim($tmp[1]));
-	}
-
-	public static function _getSbcNetworkInfo($bc, $ba = null, $isgw = null) {
-		$info['ports'] = $bc->get('root', 'lan-ports');
-		$info['mode'] = (strlen($bc->get('root', 'lan-mode')) ? $bc->get('root', 'lan-mode') : 'single');
-
-		// get names of interfaces
-		switch ($info['mode']) {
-			case 'lan-wan':
-				$wan_iface = 'eth0.11';
-			case 'single':
-				$lan_iface = 'eth0' . (($info['ports'] == 2) ? '.10' : '');
-				break;
-			case 'bonding':
-				$lan_iface = 'eth0';
-				break;
-		}
-
-		// get lan-info
-		$lanGw = false;
-		$info['iface']['lan']['macaddr'] = self::getNetworkMacAddr($lan_iface);
-		$info['iface']['lan']['ipaddr'] = self::getNetworkIpAddr($lan_iface);
-		$info['iface']['lan']['netmask'] = self::getNetworkMask($lan_iface);
-		if (in_array($bc->get('root', 'gateway-mode'), array('eth0.10', 'manual'))) {
-			$info['provided']['gateway'] = self::getNetworkGateway($lan_iface);
-			$lanGw = strlen($info['provided']['gateway']) > 0;
-		}
-
-		// get wan-info
-		if ($info['mode'] == 'lan-wan') {
-			$info['iface']['wan']['macaddr'] = self::getNetworkMacAddr($wan_iface);
-			$info['iface']['wan']['ipaddr'] = self::getNetworkIpAddr($wan_iface);
-			$info['iface']['wan']['netmask'] = self::getNetworkMask($wan_iface);
-			if (!$lanGw && in_array($bc->get('root', 'gateway-mode'), array($wan_iface, 'manual'))) {
-				$info['provided']['gateway'] = self::getNetworkGateway($wan_iface);
-			}
-		}
-
-		if ($bc->get('root', 'gateway-mode') == 'manual') {
-			$info['provided']['gateway'] = $bc->get('root', 'lan-gateway');
-		}
-
-		// get dns-config
-		$info['provided']['nameserver'] = self::getNetworkNameserver();
-
 		return($info);
 	}
 
-	public static function getNetworkNameserver() {
-		$info = array();
-		foreach (file('/etc/resolv.conf') as $line) {
-			if (strstr($line, 'nameserver')) {
-				$info[] = end(explode(" ", $line));
+	public static function getMspFirmwareVersion($is_sbc_vm = 0, $bc = null, $ba = null, $isgw = null) {
+		// cloud sbc
+		if ($is_sbc_vm || is_null($isgw)) {
+			return(null);
+		}
+		// std sbc
+		$msp = explode(':', $isgw->Query('fw'));
+		return($msp[1]);
+	}
+	
+	public static function getFirmwareVersion() {
+		if (file_exists ('/usr/local/FILENAME')) {
+			foreach (file('/usr/local/FILENAME') as $line) {
+				$firmware_version = str_replace("\n", "", $line);
+				$firmware_version = preg_replace("/^appfs-/", "", $firmware_version);
+				$firmware_version = preg_replace("/.tar.gz$/", "", $firmware_version);
+				return $firmware_version;
 			}
 		}
-		return $info;
+		return("");
 	}
 
-	private static function _getSbcvmNetworkInfo($bc, $ba = null, $isgw = null, $conf = '/etc/beroNet/sbc.conf') {
-		$sbc_conf = parse_ini_file($conf);
-		$info['wan']['ipaddr'] = $sbc_conf['SBCVM_IP'];
-		$info['wan']['netmask'] = '255.255.255.255';
-		if ($bc->get('root', 'is-vpn-running') == 1) {
-			$info['lan/vpn']['ipaddr'] = self::getNetworkIpAddr('tun0', 1);
-			$info['lan/vpn']['netmask'] = self::getNetworkMask('tun0', 1);
+	public static function getSip2SipLicences($is_sbc_vm = 0, $bc = null, $ba = null, $isgw = null) {
+		if (is_null($isgw) || !file_exists('/usr/local/www/berogui/includes/variables.php') || !file_exists('/usr/local/www/berogui/includes/Helper/HelperSip.php')) {
+			return(null);
 		}
-		return $info;
-	}
-
-	private static function _getSbcSerial($bc = null, $ba = null, $isgw = null) {
-		return(trim(file_get_contents('/sys/class/beronet/gateway/serial')));
-	}
-
-	private static function _getSbcvmSerial($bc = null, $ba = null, $isgw = null) {
-		if (is_null($bc)) {
-			$bc = new beroConf('root');
-		}
-		return $bc->get('root', 'sbcvm-serial');
-	}
-
-	public static function _getSbcStorage($bc = null, $ba = null, $isgw = null) {
-		$output = array();
-		$storage = array();
-		$translate = array(
-			5 => 'Root (Rootfs)',
-			6 => 'Firmware (Appfs)',
-			7 => 'Apps (UserApps)',
-			8 => 'Configuration (Conffs)',
-		);
-		self::exec(0, 'df', $output);
-		foreach ($output as $entry) {
-			if (preg_match('/^.*mtdblock(?<which>[0-9]+).* (?<used>[0-9]+)%.*$/', $entry, $matched)) {
-				$storage[$translate[$matched['which']]] = "{$matched['used']}%";
-				unset($matched);
-			}
-		}
-		return($storage);
-	}
-
-	private static function _getSbcUptime($bc = null, $ba = null, $isgw = null) {
-		$info = array();
-		exec('/usr/bin/uptime', $resup);
-		preg_match("/(?<t>.+), load /", $resup[0], $uptime);
-		return $uptime[1];
-	}
-
-	private static function _getSbcvmUptime($bc = null, $ba = null, $isgw = null) {
-		$time = self::convertSecondsToDaily(@file_get_contents('/proc/uptime'));
-		return "{$time['d']}d:{$time['h']}h:{$time['m']}m:{$time['s']}s";
-	}
-
-	private static function _getSbcvmVpnClient($bc = null, $ba = null, $isgw = null) {
-		require_once('/usr/local/www/berogui/modules/Vpn/vpn_helper.php');
-		return VpnHelper::getDataClients();
-	}
-
-	private static function _getSip2SipLicences($bc = null, $ba = null, $isgw) {
 		include_once('/usr/local/www/berogui/includes/variables.php');
 		require_once('/usr/local/www/berogui/includes/Helper/HelperSip.php');
-		return HelperSip::getSip2SipLicenses($isgw);
+		return(HelperSip::getSip2SipLicenses($isgw));	
+	}
+
+	public static function getVpnClient($is_sbc_vm = 0, $bc = null, $ba = null, $isgw = null) {
+		// cloud sbc
+		if ($is_sbc_vm && file_exists('/usr/local/www/berogui/modules/Vpn/vpn_helper.php')) {
+			require_once('/usr/local/www/berogui/modules/Vpn/vpn_helper.php');
+			return(VpnHelper::getDataClients());
+		}
+		// std sbc
+		return(null);
 	}
 	/* */
 
-	/**
-	 * @return string Gateway type
-	 */
-	public static function getType() {
-		if (file_exists('/sys/class/beronet/gateway/type')) {
-			return(trim(file_get_contents('/sys/class/beronet/gateway/type')));
-		}
-		return null;
-	}
-
-	/**
-	 * @return int Gateway channels
-	 */
-	public static function getChannels() {
-		// function never used
-		if (file_exists('/sys/class/beronet/gateway/channels')) {
-			return(trim(file_get_contents('/sys/class/beronet/gateway/channels')));
-		}
-		return null;
-	}
-
-	/**
-	 * @return int Reset jumper connected or not
-	 */
-	public static function getResetJumper() {
-		if (file_exists('/sys/class/beronet/gateway/resetjumper')) {
-			return(trim(file_get_contents('/sys/class/beronet/gateway/resetjumper')));
-		}
-		return null;
-	}
-
-	public static function getAppFsVersion() {
-		return self::_getAppFsVersion();
-	}
-
-	public static function getRootFsVersion() {
-		return self::_getRootFsVersion();
-	}
-
-	/**
-	 * @param string $Name
-	 * @return string name of network interface
-	 */
-	public static function getNetworkIfaceByName($name = 'lan', $bc = null) {
-		if (is_null($bc)) {
-			$bc = new beroConf('root');
-		}
-
-		$ports = $bc->get('root', 'lan-ports');
-		$mode = $bc->get('root', 'lan-mode');
-		$vlan['enable'] = $bc->get('root', 'vlan-enable');
-		$vlan['id'] = $bc->get('root', 'vlan-id');
-
-		switch ($name) {
-			case 'vpn':
-				// lan interface is always 'tun0' if OpenVPN is installed
-				if (file_exists('/apps/openvpn/VERSION')) {
-					return('tun0');
-				}
-				break;
-			case 'lan':
-				switch ($mode) {
-					default:
-					case 'single':
-						// vlan works as of now only on single iface-devices
-						if (($vlan['enable'] == 1) && ($vlan['id'] > 0)) {
-							return('eth0.' . $vlan['id']);
-						}
-					case 'lan-wan':
-						return('eth0' . (($ports == 2) ? '.10' : ''));
-					case 'bonding':
-						return('eth0');
-				}
-				break;
-			case 'wan':
-				if ($mode == 'lan-wan') {
-					return('eth0.11');
-				}
-				break;
-		}
-
-		return(false);
-	}
-
-	public static function getNetworkMacAddr($Iface = 'eth0') {
-		if (file_exists("/sys/class/net/$Iface/address")) {
-			return(trim(file_get_contents('/sys/class/net/' . $Iface . '/address')));
-		}
-		return "";
-	}
-
-	public static function getNetworkIpAddr($Iface = 'eth0', $is_sbc_vm = 0) {
-		$cmd = array(
-			0	=> '/usr/bin/expr match "$(/sbin/ifconfig '. $Iface .')" ".*inet addr:\([0-9\.]*\)"',
-			1	=> '/usr/bin/expr match "$(/usr/sbin/ifconfig '. $Iface .')" ".*inet \([0-9\.]*\)"',
-		);
-		return trim(self::exec($is_sbc_vm, $cmd[$is_sbc_vm]));
-	}
-
-	public static function getNetworkMask($Iface = 'eth0', $is_sbc_vm = 0) {
-		$cmd = array(
-			0	=> '/usr/bin/expr match "$(/sbin/ifconfig '. $Iface .')" ".* Mask:\([0-9\.]*\)"',
-			1 => '/usr/bin/expr match "$(/usr/sbin/ifconfig '. $Iface .')" ".* netmask \([0-9\.]*\)"',
-		);
-		return trim(self::exec($is_sbc_vm, $cmd[$is_sbc_vm]));
-	}
-
-	public static function getNetworkGateway($Iface = 'eth0', $is_sbc_vm = 0) {
-		return self::exec($is_sbc_vm, '/usr/bin/expr match "$(/sbin/route -n | grep ' . $Iface . ' | grep UG)" "0.0.0.0 *\([0-9\.]*\)"');
-	}
-
 	static public function getTotalCalls() {
 		require_once ('/usr/local/www/berogui/includes/isgwtelnet.php');
 		$isgw = new isgwtelnet();
@@ -1067,22 +666,6 @@ class Helper {
 		return $i;
 	}
 
-	static public function getAppList() {
-		$ret = array();
-		if (!($dh = @opendir('/home/admin/apps/'))) {
-			return $ret;
-		}
-
-		while (($file = readdir($dh)) !== false) {
-			if (($file == '.') || ($file == '..')) {
-				continue;
-			}
-			$ret[] = $file;
-		}
-		closedir($dh);
-
-		return $ret;
-	}
 
 	static public function getConfigFromIsgw($is_sbc_vm = 0) {
 		$cmd = array(
@@ -1269,7 +852,6 @@ class Helper {
 		if (is_array($postInput)) {
 			foreach ($postInput as $key => $value) {
 				if (!isset($postCheckor[$key]) || !(Helper::checkInputData($postCheckor[$key], $value, count($list_options) > 0 ? $list_options[$key] : ''))) {
-					//TODO: line can be removed echo "problem POST request:<br/><br/>\t key = $key<br/><br/>value:<pre>"; print_r($value); echo "</pre><br/><br/>options:<pre>"; print_r($list_options); echo "</pre><br/>";
 					$invalid = array('request' => $request, 'key' => $key, 'checkor' => $postCheckor[$key]);
 					$ptr_authorize_request = 0;
 					break;
@@ -1514,7 +1096,7 @@ class Helper {
 				case 'snmp':
 					return preg_match('/^[a-zA-Z0-9\@\#\$\%\^\*\(\)\_\-\+\/\?\{\}\[\]\.\,]*$/', $data);
 				case 'special-char':
-					return !preg_match('/[äÄöÖüÜß#$%^()[\]\'\/{}|\"<> ]+/', $data);
+					return !preg_match('/[äÄöÖüÜß#$%^()[\]\'\/{}|\"<>]+/', $data);
 				case 'str-length':
 					$lgth = strlen($data);
 					return (Helper::checkInputData('config-option', $data) && isset($options['min']) && isset($options['max']) && ($lgth >= $options['min'] && $lgth <= $options['max']));
@@ -1594,47 +1176,76 @@ class Helper {
 			}
 		}
 
-		return 	  "\t<div id='error-validator' class='text-center' style='margin-top: 5px; color: red;'>\n"
+		return 	  "\t<div id='error-validator' class='text-center' style='margin-top: 20px; color: red;'>\n"
 			. "\t\t$message"
 			. "\t</div>\n";
 	}
 
+	static public function displayErrorUpload($code) {
+		$msg = '';
+		switch ($code) {
+		case 1: // exceeds MAX_FILE_SIZE configured in php.ini
+		case 2: // exceeds MAX_FILE_SIZE configured in the form
+			$msg = FILEUPLOAD_ERROR_MAXFILESIZE;
+			break;
+		case 3:
+			$msg = FILEUPLOAD_ERROR_PARTIALLYUPLOADED;
+			break;
+		case 4:
+			$msg = FILEUPLOAD_ERROR_NOTUPLOADED;
+			break;
+		case 6: // should not happen
+			$msg = FILEUPLOAD_ERROR_TMPMISSING;
+			break;
+		case 7:
+			$msg = FILEUPLOAD_ERROR_WRITE;
+			break;
+		case 8:
+			$msg = FILEUPLAOD_ERROR_EXTENSION;
+			break;
+		case 999:
+		default:
+		  $msg = FILEUPLOAD_ERROR_UNKNOWN;
+		}
+		return("<div id='error-upload' class='text-center' style='margin-top:20px;color:red;'>$msg</div>\n");
+	}
+
 	static public function addGracefulToCrontab($action, $overwrite = null, $cron_path = '/usr/conf/cron/root') {
-        	$crontab = file_get_contents($cron_path);
-        	$graceful_sh = '/usr/local/sbin/graceful-action.sh';
-        	$line = "*/1 * * * * $graceful_sh $action";
-        	if (preg_match("/". str_replace('/', '\/', $graceful_sh) ."/", $crontab) && is_array($overwrite)) {
-        	        // overwrite reboot by activate
-        	        $crontab = preg_replace("/graceful-action.sh {$overwrite['old']}/", "graceful-action {$overwrite['new']}", $crontab);
-        	        file_put_contents($cron_path, $crontab);
-        	}
-        	else {
-        	        file_put_contents($cron_path, $line, FILE_APPEND);
-        	}
-        	// restart crond
-        	exec('/etc/init.d/S45cron restart');
+		$crontab = file_get_contents($cron_path);
+		$graceful_sh = '/usr/local/sbin/graceful-action.sh';
+		$line = "*/1 * * * * $graceful_sh $action";
+		if (preg_match("/". str_replace('/', '\/', $graceful_sh) ."/", $crontab) && is_array($overwrite)) {
+			// overwrite reboot by activate
+			$crontab = preg_replace("/graceful-action.sh {$overwrite['old']}/", "graceful-action {$overwrite['new']}", $crontab);
+			file_put_contents($cron_path, $crontab);
+		}
+		else {
+			file_put_contents($cron_path, $line, FILE_APPEND);
+		}
+		// restart crond
+		self::exec(0, '/etc/init.d/S36cron restart');
 	}
 
 	static public function removeGracefulToCrontab() {
-        	$apply = false;
-        	$cron_str = '';
-        	$cron_path = '/usr/conf/cron/root';
-        	$cron_tasks = file_get_contents($cron_path);
-        	// activate
-        	foreach (explode("\n", $cron_tasks) as $cron_task) {
-               	 	if (strlen($cron_task) > 0) {
-                	        if (preg_match('/graceful-action.sh/', $cron_task)) {
-                	                $apply = true;
-                	        }
-                	        else {
-                	                $cron_str .= "$cron_task\n";
-                	        }
-                	}
-        	}
-        	// restart cron
-        	file_put_contents($cron_path, $cron_str);
-        	exec('/etc/init.d/S45cron restart');
-        	return $apply;
+		$apply = false;
+		$cron_str = '';
+		$cron_path = '/usr/conf/cron/root';
+		$cron_tasks = file_get_contents($cron_path);
+		// activate
+		foreach (explode("\n", $cron_tasks) as $cron_task) {
+			if (strlen($cron_task) > 0) {
+				if (preg_match('/graceful-action.sh/', $cron_task)) {
+					$apply = true;
+				}
+				else {
+					$cron_str .= "$cron_task\n";
+				}
+			}
+		}
+		// restart cron
+		file_put_contents($cron_path, $cron_str);
+		self::exec(0, '/etc/init.d/S36cron restart');
+		return $apply;
 	}
 
 	static public function cleanCronDirectories($script, $directory_list) {
@@ -1740,36 +1351,6 @@ class Helper {
 		return ob_get_clean() ."\n";
 	}
 
-	public static function jsonEncode($data, $flags = 0) {
-		if (PHP_VERSION == '5.2.6') {
-			$encoded = '{';
-			foreach ($data as $key => $value) {
-				if (is_array($value)) {
-					$encoded .= "\"$key\":". self::jsonEncode($value) .",";
-					continue;
-				}
-				$encoded .= "\"$key\":\"". trim(str_replace('"', '\"', defined($value) ? constant($value) : $value)) ."\",";
-			}
-			$encoded = substr($encoded, 0, -1);
-			$encoded .= "}";
-			return $encoded;
-		}
-		return json_encode($data, $flags);
-	}
-
-	public static function buildIniString($data, $str = '') {
-		foreach ($data as $key => $value) {
-			if (is_array($value)) {
-				$str .= "[$key]\n";
-				$str = 	self::buildIniString($value, $str);
-			}
-			else {
-				$str .= "$key=\"$value\"\n";
-			}
-		}
-		return $str;
-	}
-
 	public static function getGuiMode($ba = null) {
 		$ba = is_null($ba) ? new beroAri() : $ba;
 		return $ba->get('gui_mode');
@@ -1854,16 +1435,26 @@ class Helper {
 								. ob_get_clean();
 				}
 				break;
-			case 'rootfs-phpcgi-failed':
+			case 'reproduce-succeeded':
+				$color = 'green';
+			case 'reproduce-failed':
 				$value = $bc->get('root', $which);
+			case 'rootfs-phpcgi-failed':
+				$value = strlen($value) ? $value : $bc->get('root', $which);
 				if (strlen($value) == 0) {
 					return('');
 				}
-				else if (preg_match('/^(.*):(.*):([0-9]*)$/', $value, $matched)) {
-					$message .= constant($matched[1]).'<br/>'.constant($matched[2]).'<br/>('.round($matched[3] * 0.001, 1).'MB)';
+				else if (preg_match('/^(.*):(.*):([0-9]+)$/', $value, $matched)) {
+					$message .= constant($matched[1]).'<br/>'.constant($matched[2]).'<br/>('.round($matched[3] * 0.001, 1).'MB required)';
 				}
-				else if (preg_match('/^(.*):(.*)$/', $value, $matched)) {
-					$message .= constant($matched[1]).'<br/>'.constant($matched[2]);
+				else if (preg_match('/^(.*):([0-9]+)$/', $value, $matched)) {
+					$message .= constant($matched[1]).'<br/>('.round($matched[2] * 0.001, 1).'MB required)';
+				}
+				else if (preg_match('/(.*):(.*)$/', $value, $matched)) {
+					$message .= constant($matched[2]).'<br/>'.constant($matched[2]);
+				}
+				else if (preg_match('/^(.*)$/', $value, $matched)) {
+					$message .= constant($matched[1]);
 				}
 				else {
 					$message .= constant($value);
@@ -1895,6 +1486,21 @@ class Helper {
 		return($message);
 	}
 
+	static public function checkRootfsPackages() {
+		foreach (array('rootfs', 'recoverygui', 'lighttpd') as $pkg) {
+			$showWarning = true;
+			if (file_exists("/pkginfo/VERSION.$pkg")) {
+				extract(@parse_ini_file("/pkginfo/VERSION.$pkg"));
+				$showWarning = !($PKG_VERSION != 1 && $PKG_VERSION != 999);
+				unset($PKG_VERSION);
+			}
+			if ($showWarning) {
+				return("\n\t<div class='text-center' style='margin-top:25px;color:red;'>". ROOTFS_INSTALLATION_WARNING ."</div>\n");
+			}
+		}
+		return('');
+	}
+
 	static public function setDataValidator($parameters, &$list_data = array(), &$options_data = array()) {
 		foreach ($parameters as $key => $param) {
 			$list_data[$key] = $param['validator'];
@@ -1920,149 +1526,6 @@ class Helper {
 		return str_replace($what_truncate, '', $string);
 	}
 
-	## // BERONODE FUNCTIONS \\ ##
-	static public function isBeronodeRunning(&$error = null) {
-		require_once('/usr/local/php/include/beronode/ServerApi.php');
-		$server_api = new ServerApi();
-		$res = $server_api->state();
-		if ($res['state'] == 'RUNNING') {
-			return true;
-		}
-		$error = $server_api->getError();
-		return false;
-	}
-
-	## // COMMAND FUNCTIONS \\ ##
-	static public function beronodeCommand($cmd) {
-		require_once('/usr/local/php/include/beronode/Api.php');
-		$node_api = new Api();
-		$response = $node_api->exec($cmd);
-		if ($node_api->hasError()) {
-			$error = $node_api->getError();
-			throw new Exception($error['msg'], $error['code']);
-		}
-		return isset($response['success']);
-	}
-
-	static public function chown($is_sbc_vm, $owner, $group, $file, $options = array()) {
-		if ($is_sbc_vm) {
-			try {
-				return self::beronodeCommand("chown ". implode(" ", $options) ." $owner:$group $file");
-			}
-			catch (Exception $e) {
-				throw $e;
-			}
-		}
-		return chown($file, $group);
-	}
-
-	static public function chmod($is_sbc_vm, $file, $privileges, $options = array()) {
-		if ($is_sbc_vm) {
-			try {
-				return self::beronodeCommand("chmod $privileges $file");
-			}
-			catch (Exception $e) {
-				throw $e;
-			}
-		}
-		return chmod($file, $privileges);
-	}
-
-	static public function copy($is_sbc_vm, $source, $dest) {
-		if ($is_sbc_vm) {
-			try {
-				return self::beronodeCommand("cp '$source' '$dest'");
-			}
-			catch (Exception $e) {
-				throw $e;
-			}
-		}
-		return copy($source, $dest);
-	}
-
-	static public function exec($is_sbc_vm, $cmd, &$output = null, $options = array()) {
-		if ($is_sbc_vm) {
-			require_once('/usr/local/php/include/beronode/Api.php');
-			$node_api = new Api();
-			$response = $node_api->exec($cmd, $options);
-			// response without error
-			if (isset($response['success'])) {
-				$output = (isset($response['output']) ? $response['output'] : '');
-				return $output;
-			}
-			// error between berogui / beronode
-			else if ($node_api->hasError()) {
-				$output = $node_api->getError();
-				return false;
-			}
-			// command error
-			$output = $response['error'];
-			return $output;
-		}
-		$res = exec($cmd, $output);
-		return $res;
-	}
-
-	static public function mkdir($is_sbc_vm, $directory, $permissions = 0777, $recursive = false) {
-		if ($is_sbc_vm) {
-			try {
-				$_R = $recursive ? "-p" : "";
-				self::beronodeCommand("mkdir $_R $directory");
-			}
-			catch (Exception $e) {
-				throw $e;
-			}
-		}
-		return mkdir($directory, $permissions, $recursive);
-	}
-
-	static public function rmdir($is_sbc_vm, $dir) {
-		if ($is_sbc_vm) {
-			try {
-				self::beronodeCommand("rm -rf '$dir'");
-			}
-			catch (Exception $e) {
-				throw $e;
-			}
-		}
-		return rmdir($dir);
-	}
-
-	static public function system($is_sbc_vm, $cmd, &$output = null, $options = array()) {
-		if ($is_sbc_vm) {
-			require_once('/usr/local/php/include/beronode/Api.php');
-			$node_api = new Api();
-			$response = $node_api->exec($cmd, $options);
-			// response without error
-			if (isset($response['success'])) {
-				$output = (isset($response['output']) ? $response['output'] : '');
-				return true;
-			}
-			// error between berogui / beronode
-			else if ($node_api->hasError()) {
-				$error = $node_api->getError();
-				throw new Exception($error['msg'], $error['code']);
-			}
-			// command error
-			$output = $response['error'];
-			return false;
-		}
-		system($cmd, $retval);
-		return $retval;
-	}
-
-	static public function unlink($is_sbc_vm, $file) {
-		if ($is_sbc_vm) {
-			try {
-				return self::beronodeCommand("rm -f '$file'");
-			}
-			catch (Exception $e) {
-				throw $e;
-			}
-		}
-		return @unlink($file);
-	}
-
 	## // REDIRECT FUNCTIONS \\ ##
 	static public function redirectAfterSubmit($db, $m, $uri = '') {
 		//if ($db->is_error()) {
