@@ -12,8 +12,9 @@ require_once "/usr/local/www/berogui/includes/profileParser.php";
 class HelperSip {
 
 	public static $fields = array("name", "sip_proxy", "sip_registrar", "sip_domain", "user", "auth_user", "displayname", "secret",
-		"sip_transport", "stunserver", "externip", "register", "validation", "regrefresh", "register_option", "sip_custom_port",
-		"config", "matchtype", "enum_support", "enum_search_domains", "keepalive_interval", "call_transfer_method", "sip_stack",
+		"sip_transport", "stunserver", "externip", "register", "validation", "regrefresh", "regrefresh_failed", "register_option", "sip_custom_port",
+		"config", "matchtype", "enum_support", "enum_search_domain", "keepalive_interval", "call_transfer_method", "sip_stack",
+		"dns_change_registration_behaviour", "dns_change_minimum_registration_time",
 		"t38", "ie_on_sip", "wait_for_cancel", "dtmfmode", "s2i_cpt",
 		"i2s_cpt", "failover_proxy", "failover_timeout", "sip_national_code", "sip_international_code",
 		"isdn2sip_destination_numformat", "isdn2sip_source_numformat", "dialplan_international_prefix", "sip2dialplan_dad_prefix_setting",
@@ -47,10 +48,11 @@ class HelperSip {
                   		'id_upd' => 'id', 'dummy' => 'password',
                         	// SETTINGS
                        		'name'       => 'group-name'  , 'alt_name'      => 'group-name'  , 'sip_proxy'       => 'hostname' , 'sip_registrar'    => 'hostname'     , 'sip_domain' => 'hostname', 'user'         => 'special-char' ,
-                        	'auth_user'  => 'special-char', 'displayname'   => 'special-char', 'matchtype'       => 'select'   , 'matchtype_manual' => 'config-option', 'profile'    => 'select'  , 'secret'       => 'config-option',
+                        	'auth_user'  => 'special-char', 'displayname'   => 'config-option', 'matchtype'       => 'select'   , 'matchtype_manual' => 'config-option', 'profile'    => 'select'  , 'secret'       => 'config-option',
                         	'sip_stack'  => 'select'      , 'sip_transport' => 'select'      , 'sip_custom_port' => 'int-range', 'register'         => 'bool'         , 'validation' => 'bool'    , 'regrefresh_on_validation_fail' => 'bool'    , 'enum_support' => 'bool'         ,
-
-                        	'enum_search_domains' => 'hostname', 'call_transfer_method' => 'select', 'option' => 'select', 'stunserver' => 'hostname', 'regrefresh' => 'int-range', 'keepalive_interval' => 'int-range', 'externip' => 'hostname',
+                        	'dns_change_registration_behaviour'  => 'select',
+                        	'dns_change_minimum_registration_time'  => 'int-range',
+                        	'enum_search_domain' => 'hostname', 'call_transfer_method' => 'select', 'option' => 'select', 'stunserver' => 'hostname', 'regrefresh' => 'int-range', 'regrefresh_failed' => 'int-range', 'keepalive_interval' => 'int-range', 'externip' => 'hostname',
                         	// MEDIA
                         	't38' => 'bool', 'dtmfmode' => 'select', 'srtp_mode' => 'select', 'srtp_crypto_suites' => 'select', 'codecs' => 'select',
                         	// CALLPROGRESS
@@ -67,26 +69,27 @@ class HelperSip {
 	
 	                        'from_sip_src_setting' => 'select', 'from_sip_src_setting_manual' => 'config-option', 'from_sip_dest_setting' => 'select', 'from_sip_dest_setting_manual' => 'config-option',
                	   			// MORE
-				'failover_proxy'=> 'group-name'	, 'failover_timeout' => 'int-range'	, 's2s_nat_opener' 	=> 'select'		, "qvalue" => 'select', 
-				'dnssrv' 	=> 'bool'	, 'tr_notruf' => 'bool'			, 'addit_options' 	=> 'config-option'	, 'callgroup_name' => 'alphanumeric', 'callgroup_priority' => 'int-range', 'max_simultaneous_calls' => 'int-range', "s2s_rtp_handling_method" => 'select', 'sips_on_tls' => 'bool', '1tr119' => 'bool'
+							'failover_proxy'=> 'group-name'	, 'failover_timeout' => 'int-range'	, 's2s_nat_opener' 	=> 'select'		, "qvalue" => 'select', 
+							'dnssrv' 	=> 'bool'	, 'tr_notruf' => 'bool'			, 'addit_options' 	=> 'config-option'	, 'callgroup_name' => 'alphanumeric', 'callgroup_priority' => 'int-range', 'max_simultaneous_calls' => 'int-range', "s2s_rtp_handling_method" => 'select', 'sips_on_tls' => 'bool', '1tr119' => 'bool'
                   	   );
 
 		$options = array(
-                			'call_transfer_method'                  => array('refer', 'reinvite'),
+                				'call_transfer_method'                  => array('refer', 'reinvite'),
                         		'codecs'                                => $options_pre_loaded['codecs'],
                         		'dtmfmode'                              => array('info', 'inband', 'rfc2833'),
-                        		'failover_timeout'                      => array('min' => 0, 'max' => '60'),
+                        		'failover_timeout'                      => array('min' => 0, 'max' => 60),
                         		'from_sip_dest_setting'                 => $options_pre_loaded['from_sip_dest_setting'],
                         		'from_sip_src_setting'                  => $options_pre_loaded['from_sip_src_setting'],
                         		'isdn2sip_destination_numformat'        => $options_pre_loaded['number_format'],
                         		'isdn2sip_source_numformat'             => $options_pre_loaded['number_format'],
                         		'keepalive_interval'                    => array('min' => 0, 'max' => 86400),
-					'matchtype'				=> array('address', 'fromuser', 'touser', 'contactuser', 'requesturluser', 'manual'),
+								'matchtype'								=> array('address', 'fromuser', 'touser', 'contactuser', 'requesturluser', 'manual'),
                         		'option'                                => array('nonat', 'stun', 'externip'),
                         		'profile'                               => array('manual'), // only manual allowed
                         		'qvalue'                                => $options_pre_loaded['qvalue'],
                         		's2s_rtp_handling_method'               => $options_pre_loaded['s2s_rtp_handling_method'],
                         		'regrefresh'                            => array('min' => 30, 'max' => 86400),
+                        		'regrefresh_failed'                     => array('min' => 10, 'max' => 3600),
                         		's2s_nat_opener'                        => $options_pre_loaded['s2s_nat_opener'],
                         		'sip_contact_user_setting'              => $options_pre_loaded['sip_from_setting'],
                         		'sip_custom_port'                       => array('min' => 1025, 'max' => 65535),
@@ -103,7 +106,9 @@ class HelperSip {
                         		'srtp_mode'                             => array('off', 'optional', 'mandatory', 'off:optional', 'off:mandatory', 'optional:off', 'optional:mandatory', 'mandatory:off', 'mandatory:optional'),
                         		'use_privacy_header'                    => $options_pre_loaded['privacy_header'],
                         		'callgroup_priority'                    => array('min' => 0, 'max' => 100),
-                        		'max_simultaneous_calls'               => array('min' => 0, 'max' => 255)
+                        		'max_simultaneous_calls'                => array('min' => 0, 'max' => 255),
+                        		'dns_change_registration_behaviour'     => array('change_when_no_calls', 'change_immediately', 'stay_on_lower_priority'),
+                        		'dns_change_minimum_registration_time'  => array('min' => 0, 'max' => 3600)
                     		);
 
 		return array('post' => $post, 'options' => $options);
@@ -144,8 +149,7 @@ class HelperSip {
 
 	//Return text field
 	public static function textField(&$ba, $id, $col, $fixedSettings, $default = "") {
-		$option = ($col === "enum_search_domains") ? trim($col, "s") : $col;
-		$value = self::getValue($ba, $id, $option, $fixedSettings);
+		$value = self::getValue($ba, $id, $col, $fixedSettings);
 		if ($default !== "" && $value == "") {
 			$value = $default;
 		}
@@ -163,7 +167,7 @@ class HelperSip {
 	//Return a dropdown field
 	public static function dropdown(&$ba, $id, $col, $fixedSettings, $options, $default = "") {
 		$value = self::getValue($ba, $id, $col, $fixedSettings);
-		$sel .= "<select class='form-control input-sm' name='" . $col . "'>";
+		$sel = "<select class='form-control input-sm' id='" . $col . "' name='" . $col . "'>";
 		if ($value !== "") {
 			$default = $value;
 		}
@@ -174,8 +178,6 @@ class HelperSip {
 		return $sel;
 	}
 
-
-
 	//Return a checkbox
 	public static function checkbox(&$ba, $id, $col, $fixedSettings, $htmlOptions = "", $default = "") {
 	
@@ -352,48 +354,21 @@ class HelperSip {
 		return $type . $profile;
 	}
 
+
 	public static function matchtype(&$ba, $id, $fixedSettings) {
-		$option = self::getValue($ba, $id, "matchtype", $fixedSettings);
-		$manual = self::getValue($ba, $id, "matchtype_manual", $fixedSettings);
-		$option = explode("|", $option);
-		(in_array("address", $option) || $option[0] == "") ? $checked = "checked" : $checked = "";
-		$checkbox .= "<div class='checkbox pull-left'>"
-			. "<label><input type='checkbox' name='matchtype[]' id='address' value='address' $checked>IP Address</label>"
-			. "</div>";
+		$defaultArray = array('address' => 'IP Address', 'fromuser' => 'From User', 'touser' => 'To User', 'contactuser' => 'Contact User', 'requesturluser' => 'Request URI User', 'manual' => 'Manual', );
+		$options = self::getValue($ba, $id, "matchtype", $fixedSettings);
+		$options = explode("|", $options);
+		
+		if ($options[0] == "") { $options[0] = 'address'; } //set default matchtype (ip adress)
 
-		(in_array("fromuser", $option)) ? $checked = "checked" : $checked = "";
-		$checkbox .= "<div class='clearfix'></div>"
-			. "<div class='checkbox pull-left'>"
-			. "<label><input type='checkbox' name='matchtype[]' value='fromuser' $checked>From User</label>"
-			. "</div>";
+		$sel = "<select name='matchtype[]' class='form-control input-sm' id='matchtype' multiple='true' style='height:102px;'>";
+		foreach ($defaultArray as $value => $name) {
+			in_array($value, $options) ? $sel.= "<option value='" . $value . "' selected>" . $name . "</option>" : $sel.= "<option value='" . $value . "'>" . $name . "</option>";
+		}
+		$sel.="</select>";
 
-		(in_array("touser", $option)) ? $checked = "checked" : $checked = "";
-		$checkbox .= "<div class='clearfix'></div>"
-			. "<div class='checkbox pull-left'>"
-			. "<label><input type='checkbox' name='matchtype[]' value='touser' $checked>To User</label>"
-			. "</div>";
-
-		(in_array("contactuser", $option)) ? $checked = "checked" : $checked = "";
-		$checkbox .= "<div class='clearfix'></div>"
-			. "<div class='checkbox pull-left'><label><input type='checkbox' name='matchtype[]' value='contactuser' $checked>Contact User</label>"
-			. "</div>";
-
-		(in_array("requesturluser", $option)) ? $checked = "checked" : $checked = "";
-		$checkbox .= "<div class='clearfix'></div>"
-			. "<div class='checkbox pull-left'>"
-			. "<label><input type='checkbox' name='matchtype[]' value='requesturluser' $checked>Request-URI User</label>"
-			. "</div>";
-
-		(in_array("manual", $option)) ? $checked = "checked" : $checked = "";
-		$checkbox .= "<div class='clearfix'></div>"
-			. "<div class='checkbox pull-left'>"
-			. "<label><input type='checkbox' name='matchtype[]' id='manual' value='manual' $checked>Manual</label>"
-			. "</div>";
-		$checkbox .= "<div class='clearfix'></div>"
-			. "<div class='checkbox pull-left'>"
-			. "<label><input name='matchtype_manual' class='form-control input-sm' value='" . $manual . "' size='14' /></label>"
-			. "</div>";
-		return $checkbox;
+		return $sel;
 	}
 	
 	public static function udpports(&$ba) {
