@@ -6,5 +6,6 @@ if (!isset($skip_session) && !$skip_session) {
 }
 
 $fileManager=new fileManagement();
-$fileManager->activate();
+$fileManager->activate(true, array(), false, isset($goToUpdateMode));
 
+?>
