@@ -7,6 +7,10 @@
  *
  * @author Miguel Palmer <mp@beronet.com>
  */
+
+require_once('/usr/fallback/beroConf.php');
+require_once("/usr/www/include/SQLite2ToSQLite3.php");
+
 class fileManagement {
 
 	private $_is_sbc_vm = false;
@@ -24,11 +28,15 @@ class fileManagement {
 	private $conf_folder;
 
 	public function __construct() {
-		include "/usr/local/www/berogui/includes/variables.php";
-		include_once("/usr/www/include/SQLite2ToSQLite3.php");
-		include "/usr/local/www/berogui/misc/database.php";
+		if (!file_exists("/usr/local/www/berogui/includes/variables.php")
+			|| !file_exists("/usr/local/www/berogui/misc/database.php")
+			|| !file_exists('/usr/local/www/berogui/includes/Helper/Helper.php')) {
+				throw new Exception('missing scripts');
+		}
+
+		include("/usr/local/www/berogui/includes/variables.php");
+		include("/usr/local/www/berogui/misc/database.php");
 		require_once('/usr/local/www/berogui/includes/Helper/Helper.php');
-		require_once('/usr/fallback/beroConf.php');
 		$this->bc = new beroConf('root');
 		$this->ba = new beroAri();
 
@@ -252,7 +260,7 @@ class fileManagement {
 					$hw_cont .= "wait4idle=" . $this->ba->get('wait4idle') . "\n";
 				}
 
-				if ($type == "bf4FXS" || $type == "bf8FXS" || $type == "bf1FXS") {
+				if (preg_match('/bf[0-9]*FXS/', $type)) {
 					$hw_cont .= ($this->ba->get('boostringer') == "") ? "boostringer=0\n" : "boostringer=" . $this->ba->get('boostringer') . "\n";
 					$hw_cont .= "ring_oscillator_on=" . $this->ba->get('ring_oscillator_on') . "\n";
 					$hw_cont .= "ring_oscillator_off=" . $this->ba->get('ring_oscillator_off') . "\n";
@@ -310,40 +318,18 @@ class fileManagement {
 		
 
 		$isgw_cont .= "msp_bridging=YES\n";
-		$isgw_cont .= "experimental_options=" . $this->ba->get("experimental_options") . "\n";
-		$isgw_cont .= "emergency_numbers=" . $this->ba->get("emergency_numbers") . "\n";
-		
-		
-		$isgw_cont .= "blacklist_max_options_packets_lan=" . $this->ba->get("blacklist_max_options_packets_lan") . "\n";
-		$isgw_cont .= "blacklist_options_timeframe_lan=" . $this->ba->get("blacklist_options_timeframe_lan") . "\n";
-		
-		$isgw_cont .= "blacklist_max_invite_packets_lan=" . $this->ba->get("blacklist_max_invite_packets_lan") . "\n";
-		$isgw_cont .= "blacklist_invite_timeframe_lan=" . $this->ba->get("blacklist_invite_timeframe_lan") . "\n";
-		
-		$isgw_cont .= "blacklist_max_register_packets_lan=" . $this->ba->get("blacklist_max_register_packets_lan") . "\n";
-		$isgw_cont .= "blacklist_register_timeframe_lan=" . $this->ba->get("blacklist_register_timeframe_lan") . "\n";
-		
-		$isgw_cont .= "blacklist_max_other_packets_lan=" . $this->ba->get("blacklist_max_other_packets_lan") . "\n";
-		$isgw_cont .= "blacklist_other_timeframe_lan=" . $this->ba->get("blacklist_other_timeframe_lan") . "\n";
-		
-		$isgw_cont .= "blacklist_blockduration_lan=" . $this->ba->get("blacklist_blockduration_lan") . "\n";
-		
-		
-		$isgw_cont .= "blacklist_max_options_packets_wan=" . $this->ba->get("blacklist_max_options_packets_wan") . "\n";
-		$isgw_cont .= "blacklist_options_timeframe_wan=" . $this->ba->get("blacklist_options_timeframe_wan") . "\n";
-		
-		$isgw_cont .= "blacklist_max_invite_packets_wan=" . $this->ba->get("blacklist_max_invite_packets_wan") . "\n";
-		$isgw_cont .= "blacklist_invite_timeframe_wan=" . $this->ba->get("blacklist_invite_timeframe_wan") . "\n";
-		
-		$isgw_cont .= "blacklist_max_register_packets_wan=" . $this->ba->get("blacklist_max_register_packets_wan") . "\n";
-		$isgw_cont .= "blacklist_register_timeframe_wan=" . $this->ba->get("blacklist_register_timeframe_wan") . "\n";
-		
-		$isgw_cont .= "blacklist_max_other_packets_wan=" . $this->ba->get("blacklist_max_other_packets_wan") . "\n";
-		$isgw_cont .= "blacklist_other_timeframe_wan=" . $this->ba->get("blacklist_other_timeframe_wan") . "\n";
-		
-		$isgw_cont .= "blacklist_blockduration_wan=" . $this->ba->get("blacklist_blockduration_wan") . "\n";
-		
-		
+
+		$ini_array = array();
+		foreach(array(
+			'experimental_options', 'emergency_numbers', 'device_name',
+			'blacklist_max_options_packets_lan', 'blacklist_options_timeframe_lan', 'blacklist_max_invite_packets_lan', 'blacklist_invite_timeframe_lan', 'blacklist_max_register_packets_lan', 'blacklist_register_timeframe_lan',
+			'blacklist_max_other_packets_lan', 'blacklist_other_timeframe_lan', 'blacklist_blockduration_lan',
+			'blacklist_max_options_packets_wan', 'blacklist_options_timeframe_wan', 'blacklist_max_invite_packets_wan', 'blacklist_invite_timeframe_wan', 'blacklist_max_register_packets_wan', 'blacklist_register_timeframe_wan',
+			'blacklist_max_other_packets_wan', 'blacklist_other_timeframe_wan', 'blacklist_blockduration_wan',
+		) as $key) {
+			$ini_array[$key] = $this->ba->get($key);
+		}
+		$isgw_cont .= Helper::buildIniString($ini_array);
 
 		if ($this->bc->get("root", "vlan-enable") == "1") {
 			$isgw_cont .= "interface_host=eth0." . $this->bc->get("root", "vlan-id") . "\n";
@@ -353,7 +339,7 @@ class fileManagement {
 		$this->saveFile($this->conf_folder . "/isgw.conf", $isgw_cont);
 	}
 
-	private function stackSettings($network_interface, &$sip_cont, $iface_name = null) {
+	private function stackSettings($iface, $iface_name = null) {
 		$list_params = array(
 			// key => default_value
 			'stack_active' 		=> '',
@@ -365,32 +351,40 @@ class fileManagement {
 			'tos_sip'		=> '160',
 			'rtp_port_selection'	=> '',
 			'tls_verification_selection'	=> '',
+			'sip_useragent' => $iface == 'wan' ? SIP_USERAGENT_WAN_DEFAULT : SIP_USERAGENT_LAN_DEFAULT,
+			'registration_balancing'	=> '0',
+		);
+		$params = array(
+			"interface_name_$iface" => (is_null($iface_name) ? Helper::getNetworkIfaceByName($iface) : $iface_name),
 		);
 		foreach ($list_params as $key => $default) {
-			$value = $this->ba->get("{$key}_{$network_interface}");
-			$value = (strlen($value) != 0 ? $value : $default);
-			$sip_cont .= "{$key}_{$network_interface}=$value\n";
+			$value = $this->ba->get("{$key}_{$iface}");
+			$params["{$key}_{$iface}"] = (strlen($value) != 0 ? $value : $default);
 		}
-
-		$sip_cont .= "interface_name_$network_interface=". (is_null($iface_name) ? Helper::getNetworkIfaceByName($network_interface) : $iface_name) ."\n";
+		$params["sip_useragent_$iface"] = str_replace(
+			array('{MAC}', '{SERIAL}', '{MODULES}'),
+			array(Helper::getNetworkMacAddr(Helper::getNetworkIfaceByName($iface, $this->bc)), Helper::getSerial(), implode('_', Helper::getLif())),
+			$params["sip_useragent_$iface"]
+		);
+		return(Helper::buildIniString($params));
 	}
 
 	public function isgwSip() {
 		$sip_cont = "[general]\n";
 		
 		if ($this->_is_sbc_vm) {
-			$this->stackSettings('wan', $sip_cont, 'ens4');
+			$sip_cont .= $this->stackSettings('wan', 'ens4');
 			if ($this->bc->get('root', 'is-vpn-running')) {
-				$this->stackSettings('lan', $sip_cont, 'tun0');
+				$sip_cont .= $this->stackSettings('lan', 'tun0');
 			}
 		}
 		else {
-			$this->stackSettings('lan', $sip_cont);
+			$sip_cont .= $this->stackSettings('lan');
 			if ($this->bc->get('root', 'lan-mode') == 'lan-wan') {
-				$this->stackSettings('wan', $sip_cont);
+				$sip_cont .= $this->stackSettings('wan');
 			}
 			if (is_dir('/home/admin/apps/openvpn/')) {
-				$this->stackSettings('vpn', $sip_cont);
+				$sip_cont .= $this->stackSettings('vpn');
 			}
 		}
 
@@ -410,9 +404,9 @@ class fileManagement {
 			$sip_cont .= "secret = " . $entry['secret'] . "\n";
 			if ($entry['register'] == '1') {
 				$sip_cont .= "regrefresh = " . $entry['regrefresh'] . "\n";
+				$sip_cont .= "regrefresh_failed = " . $entry['regrefresh_failed'] . "\n";
 				$sip_cont .= "register_options = " . $entry['register_option'] . "\n";
 			}
-			
 			$sip_cont .= "validation = " . $entry['validation'] . "\n";
 			if ($entry['validation'] == '1') {
 				$sip_cont .= "keepalive-interval = " . $entry['keepalive_interval'] . "\n";
@@ -421,7 +415,7 @@ class fileManagement {
 			
 			$sip_cont .= "externip = " . $entry['externip'] . "\n";
 			$sip_cont .= "stunserver = " . $entry['stunserver'] . "\n";
-			$sip_cont .= "config = " . str_replace(';', '\;', html_entity_decode($entry['config'])) . "\n";
+			$sip_cont .= "config = " . str_replace(';', '\;', html_entity_decode($entry['config'])) ."\n";
 			$sip_cont .= "profile = " . $entry['profile'] . "\n";
 			$sip_cont .= "matchtype = " . $entry['matchtype'] . "\n";
 			$sip_cont .= "matchtype_manual = " . $entry['matchtype_manual'] . "\n";
@@ -432,6 +426,10 @@ class fileManagement {
 			$sip_cont .= "callgroup_name = " . $entry['callgroup_name'] . "\n";
 			$sip_cont .= "callgroup_priority = " . $entry['callgroup_priority'] . "\n";
 			$sip_cont .= "max_simultaneous_calls = " . $entry['max_simultaneous_calls'] . "\n";
+			
+			$sip_cont .= "dns_change_registration_behaviour = " . $entry['dns_change_registration_behaviour'] . "\n";
+			$sip_cont .= "dns_change_minimum_registration_time = " . $entry['dns_change_minimum_registration_time'] . "\n";
+			$sip_cont .= "\n";
 		}
 
 		$sip_cont .= "\n#include " . $this->conf_folder . "isgw.sip.custom\n";
@@ -469,6 +467,7 @@ class fileManagement {
 			$isdn_cont .= "restart_after_link_loss = " . $this->pstnValue('restart_after_link_loss', $group, 'isdn') . "\n";
 			$isdn_cont .= "monitored_sip_peer = " . $this->pstnValue('monitored_sip_peer', $group, 'isdn') . "\n";
 			$isdn_cont .= "monitored_sip_peer_offtime = " . $this->pstnValue('monitored_sip_peer_offtime', $group, 'isdn') . "\n";
+			$isdn_cont .= "\n";
 		}
 
 		$isdn_cont .= "\n#include /usr/conf/isgw.isdn.custom\n";
@@ -574,7 +573,10 @@ class fileManagement {
 				$analog_cont .= "message_waiting_method = " . $this->pstnValue('message_waiting_method', $group, 'analog') . "\n";
 			}
 			$analog_cont .= "fxo_verify_ringing = " . $this->pstnValue('fxo_verify_ringing', $group, 'analog') . "\n";
+			$analog_cont .= "fxs_wink_offset = " . $this->pstnValue('fxs_wink_offset', $group, 'analog') . "\n";
+			$analog_cont .= "fxs_wink_duration = " . $this->pstnValue('fxs_wink_duration', $group, 'analog') . "\n";
 			$analog_cont .= "config = " . $this->pstnValue('config', $group, 'analog') . "\n";
+			$analog_cont .= "\n";
 		}
 
 		$analog_cont .= "\n#include /usr/conf/isgw.analog.custom\n";
@@ -625,6 +627,7 @@ class fileManagement {
 			$cas_cont .= "fxo_call_ending_signal = " . $this->pstnValue('fxo_call_ending_signal', $group, 'cas_channels') . "\n";
 			$cas_cont .= "fxo_cid_detection_mode = " . $this->pstnValue('fxo_cid_detection_mode', $group, 'cas_channels') . "\n";
 			$cas_cont .= "config = " . $this->pstnValue('config', $group, 'cas_channels') . "\n";
+			$cas_cont .= "\n";
 		}
 
 		$cas_cont .= "\n#include /usr/conf/isgw.cas.custom\n";
@@ -662,6 +665,7 @@ class fileManagement {
 			$gsm_cont .= "extensions = " . $this->pstnValue('extension', $group, 'gsm') . "\n";
 			$gsm_cont .= "chansel = " . $this->pstnValue('chansel', $group, 'gsm') . "\n";
 			$gsm_cont .= "chansel_direction = " . $this->pstnValue('chansel_dir', $group, 'gsm') . "\n";
+			$gsm_cont .= "\n";
 			//$gsm_cont.="pin = ".$pin."\n";
 			//$gsm_cont.="smsc = ".$smsc."\n";
 		}
@@ -703,7 +707,14 @@ class fileManagement {
 			$lte_cont .= "extensions = " . $this->pstnValue('extension', $group, 'lte') . "\n";
 			$lte_cont .= "chansel = " . $this->pstnValue('chansel', $group, 'lte') . "\n";
 			$lte_cont .= "chansel_direction = " . $this->pstnValue('chansel_dir', $group, 'lte') . "\n";
-			$lte_cont .= "sms_webhook= " . $this->pstnValue('sms_webhook', $group, 'lte') . "\n";
+			$lte_cont .= "sms_webhook = " . $this->pstnValue('sms_webhook', $group, 'lte') . "\n";
+			$lte_cont .= "sms_webhook_user = " . $this->pstnValue('sms_webhook_user', $group, 'lte') . "\n";
+			$lte_cont .= "sms_webhook_secret = " . $this->pstnValue('sms_webhook_secret', $group, 'lte') . "\n";
+			$lte_cont .= "sms_webhook_type= " . $this->pstnValue('sms_webhook_type', $group, 'lte') . "\n";
+			$lte_cont .= "sms_webhook_id= " . $this->pstnValue('sms_webhook_id', $group, 'lte') . "\n";
+			$lte_cont .= "wait_for_cid_timeout = " . $this->pstnValue('wait_for_cid_timeout', $group, 'lte') . "\n";
+			$lte_cont .= "lte_init_hook = " . $this->pstnValue('lte_init_hook', $group, 'lte') . "\n";
+			$lte_cont .= "\n";
 		}
 
 		$lte_cont .= "\n#include /usr/conf/isgw.lte.custom\n";
@@ -727,26 +738,61 @@ class fileManagement {
 			}
 		}
 		$conf['general'] = $params;
+
+		## cloud
+		foreach (array('_enable', '_show_status', '_key', 'Address') as $key) {
+			$conf["cloud{$key}"] = $this->bc->get('root', "cloud{$key}");
+		}
+		foreach (array('Enabled', 'Address', 'Port', 'Type', 'User', 'Secret') as $key) {
+			$conf["proxy{$key}"] = $this->bc->get('root', "proxy{$key}");
+		}
+		foreach (array('debug', 'verifyhost', 'verifypeer') as $key) {
+			$conf["openssl_$key"] = $this->bc->get('root', "openssl_$key");
+		}
+		foreach (array(
+			'gui-ntphost', 'ntphost', 'timezone', 'timezone_mode', 'time_mode','root-version', 'msp-iface', 'msp-ipaddr', 'app-image', 'app-status', 'use-boot-prov', 'tftp-host', 'tftp-url',
+			'provisioning_manual', 'provisioning_mode', 'provisioning_useragent', 'provisioning_url', 'polling_interval',
+		) as $key) {
+			$conf[$key] = $this->bc->get('root', $key);
+		}
+		
+		
+		//update /etc/TZ file if necessary
+		if (1) {
+			$timezone_mode = $this->bc->get('root', "timezone_mode");
+			$timezone_db = $this->bc->get('root', "timezone");
+			$timezone_list = Helper::getTimezoneList();
+			$timezone = $timezone_list[sqlite_escape_string($timezone_db)];
+			switch ($timezone_mode) {
+					case 'auto':
+						$update_TZ = "{$timezone['std-abbr']}{$timezone['std-offset']}{$timezone['dst-abbr']},{$timezone['rules']}";
+						break;
+					case 'summer':
+						if (preg_match('/^(-|\+)(\d+)$/', $timezone['std-offset'], $gmt_matched)) {
+							$gmt_modified = $gmt_matched[1]. (string)($gmt_matched[1] === '-' ? (int)$gmt_matched[2] + 1 : abs((int)$gmt_matched[2] - 1));
+							$update_TZ = "GMT$gmt_modified";
+						}
+						else if (preg_match('/(-|\+)(\d+):(\d+)$/', $timezone['std-offset'], $gmt_matched)) {
+							$gmt_modified = $gmt_matched[1]. (string)($gmt_matched[1] === '-' ? (int)$gmt_matched[2] + 1 : abs((int)$gmt_matched[2] - 1));
+							$update_TZ = "GMT$gmt_modified:{$gmt_matched[3]}";
+						}
+						break;
+					case 'winter':
+						$update_TZ = "{$timezone['std-abbr']}{$timezone['std-offset']}";
+					break;
+			}
+			
+			$tzfile = explode ("\n", file_get_contents("/etc/TZ"));
+			if ($tzfile[0] != $update_TZ) {
+				system("/bin/mount -o remount,rw /");
+				file_put_contents ("/etc/TZ", $update_TZ . "\n");
+			}
+		}
+
 		$m_cont = Helper::buildIniString($conf);
 		
 
 		/* OLDWAY. MUST BE UPDATED */
-		$m_cont .= "ntphost=" . $this->bc->get("root", "ntphost") . "\n";
-		$m_cont .= "timezone=" . $this->bc->get("root", "timezone") . "\n";
-		$m_cont .= "root-version=" . $this->bc->get("root", "root-version") . "\n";
-		$m_cont .= "msp-iface=" . $this->bc->get("root", "msp-iface") . "\n";
-		$m_cont .= "msp-ipaddr=" . $this->bc->get("root", "msp-ipaddr") . "\n";
-		$m_cont .= "app-image=" . $this->bc->get("root", "app-image") . "\n";
-		$m_cont .= "app-status=" . $this->bc->get("root", "app-status") . "\n";
-		$m_cont .= "use-boot-prov=" . $this->bc->get("root", "use-boot-prov") . "\n";
-		$m_cont .= "tftp-host=" . $this->bc->get("root", "tftp-host") . "\n";
-		$m_cont .= "tftp-url=" . $this->bc->get("root", "tftp-url") . "\n";
-		$m_cont .= "provisioning_manual=" . $this->bc->get("root", "provisioning_manual") . "\n";
-		$m_cont .= "provisioning_mode=" . $this->bc->get("root", "provisioning_mode") . "\n";
-		$m_cont .= "provisioning_url=" . $this->bc->get("root", "provisioning_url") . "\n";
-		$m_cont .= "polling_interval=" . $this->bc->get("root", "polling_interval") . "\n";
-
-
 		$m_cont .= "snmp-enabled=" . $this->bc->get("root", "snmp-enabled") . "\n";
 		$m_cont .= "snmpserver_enabled=" . $this->bc->get("root", "snmpserver_enabled") . "\n";
 		
@@ -787,22 +833,11 @@ class fileManagement {
 		$m_cont .= "gui_mode=" . $this->ba->get("gui_mode") . "\n";
 		$m_cont .= "lang=" . $this->ba->get("lang") . "\n";
 
-		$m_cont .= "cloud_enable=" . $this->bc->get("root", "cloud_enable") . "\n";
 		$m_cont .= "redirect_cfg=" . $this->bc->get("root", "redirect_cfg") . "\n";
-		$m_cont .= "cloud_show_status=". $this->ba->get("cloud_show_status") ."\n";
-		$m_cont .= "cloud_key=" . $this->bc->get("root", "cloud_key") . "\n";
 		$m_cont .= "userapp-enabled=" . $this->bc->get("root", "userapp-enabled") . "\n";
 		$m_cont .= "userapp-user-enabled=" . $this->bc->get("root", "userapp-enabled") . "\n";
 		$m_cont .= "system-check-enabled=" . $this->bc->get("root", "system-check-enabled") . "\n";
 		$m_cont .= "safeguard=" . $this->bc->get("root", "safeguard") . "\n";
-		$m_cont .= "cloudAddress=" . $this->ba->get('cloudAddress') . "\n";
-
-		$m_cont .= "proxyEnabled=" . $this->ba->get('proxyEnabled') . "\n";
-		$m_cont .= "proxyAddress=" . $this->ba->get('proxyAddress') . "\n";
-		$m_cont .= "proxyPort=" . $this->ba->get('proxyPort') . "\n";
-		$m_cont .= "proxyType=" . $this->ba->get('proxyType') . "\n";
-		$m_cont .= "proxyUser=" . $this->ba->get('proxyUser') . "\n";
-		$m_cont .= "proxySecret=" . $this->ba->get('proxySecret') . "\n";
 
 		$m_cont .= "summer_winter_time=" . $this->ba->get("summer_winter_time") . "\n";
 		$m_cont .= "set_hw=" . $this->ba->get("set_hw") . "\n";
@@ -869,17 +904,36 @@ class fileManagement {
 			$content .= "INPUT;" . $entry['protocol'] . ";" . $dest_port . ";" . $entry['address'] . "/" . $entry['netmask'] . ";" . $action . ";" . $entry['stack']. "\n";
 		}
 		$this->saveFile($this->conf_folder . "network.acl", $content);
+
+		## check the ACL rules: if a port is open from anywhere, we update beroconf
+		## to display a warning message
+		$ports_opened = array();
+		foreach (explode("\n", file_get_contents("{$this->conf_folder}/network.acl")) as $acl) {
+			if (preg_match('/INPUT;(tcp|udp|)?;(.*);.*\/0;ACCEPT;/', $acl, $matched)) {
+				$ports_opened[] = $matched[2];
+				unset($matched);
+			}
+		}
+		if (($key = array_search('65001', $ports_opened)) !== false) {
+			unset($ports_opened[$key]);
+		}
+		if (empty($ports_opened)) {
+			foreach(array('fw-opened', 'fw-opened-ports') as $key) {
+				$this->bc->delete('root', $key);
+			}
+		}
+		else {
+			$this->bc->set('root', 'fw-opened', 'WARNING_MESSAGE_FW_RULES_OPENED');
+			$this->bc->set('root', 'fw-opened-ports', implode(':', $ports_opened));
+		}
 	}
 
 	public function isgwDialplan() {
+		$pstn_dir = array('isdn', 'analog', 'cas', 'lte', 'gsm');
 		$d_cont = ";From\tTo\tFromID\tToID\tDestination\tNewDestination\tSource\tNewSource\tConfig\n";
 		$query_d = $this->ba->select("select * from dialplan order by posId, id asc");
 		while ($entry = $this->ba->fetch_array($query_d)) {
-			if ($entry['fromDirection']=='lte') $entry['fromDirection']='gsm'; 
-			if ($entry['toDirection']=='lte') $entry['toDirection']='gsm'; 
-
-			// TODO: replace by in_array(): simpler, faster, lighter -> the LTE check is useless since the value is updated just before
-			if (($entry['fromDirection'] == 'isdn' || $entry['fromDirection'] == 'analog' || $entry['fromDirection'] == 'gsm' ||  $entry['fromDirection'] == 'lte' || $entry['fromDirection'] == 'cas') && ($entry['toDirection'] == 'isdn' || $entry['toDirection'] == 'analog' || $entry['toDirection'] == 'gsm' || $entry['toDirection'] == 'lte' || $entry['toDirection'] == 'cas')) {
+			if ( in_array( $entry['fromDirection'] , $pstn_dir ) && in_array( $entry['toDirection'] , $pstn_dir ) ) {	
 				($entry['activ'] == "1") ? $d_cont .= $entry['fromDirection'] . "\t" : $d_cont .= ";#" . $entry['fromDirection'] . "\t";
 				//$d_cont.="isdn\t";
 				$d_cont .= "sip\t";
@@ -904,6 +958,7 @@ class fileManagement {
 				$d_cont .= stripslashes("(.*)") . "\t";
 				$d_cont .= stripslashes("\\\\1") . "\t";
 				$d_cont .= $entry['config'] . "\n";
+				
 			} else {
 
 				($entry['activ'] == "1") ? $d_cont .= $entry['fromDirection'] . "\t" : $d_cont .= ";#" . $entry['fromDirection'] . "\t";
@@ -984,7 +1039,7 @@ class fileManagement {
 					. "</html>\n";
 	}
 
-	public function activate($redirection = true, $list_type = array()) {
+	public function activate($redirection = true, $list_type = array(), $skipReboot = false, $rebootUpdateMode = false) {
 		// sip
 		$this->isgwSip();
 
@@ -1021,29 +1076,45 @@ class fileManagement {
 			$this->isgwLte();
 			$this->hardwareConf($list_type);
 
+			## reboot without reloading modules and init scripts
+			if ($rebootUpdateMode) {
+				$this->ba->set('activate', 0);
+				return;
+			}
+
 			// activate
 			$option = $this->ba->get("activate");
 			if ($option == 3) {
 				$this->ba->set('activate', '0');
-				if ($redirection == true) {
+				if ($skipReboot) {
+					// reboot managed by another features.
+					// do nothing
+				}
+				else if ($redirection) {
 					echo $this->_redirectToReboot();
 					//API Aufruf
-				} else {
+				}
+				else {
 					require_once('/usr/local/www/berogui/includes/Helper/Helper.php');
 					Helper::reboot("",true);
 				}
 			}
 			else if ($option == 2) {
 				$this->loadModules($list_type);
-				exec('/usr/local/init/S50isgw restart', $ausgabe);
-				exec('/usr/local/init/S03acl stop');
-				exec('/usr/local/init/S03acl start');
-				exec('/usr/local/init/S60cloud restart');
-				exec('/usr/local/init/S90systemlog stop');
-				exec('/usr/local/init/S90systemlog start');
-				exec('/usr/local/init/S80snmpd restart');
-				exec('/usr/local/init/S81snmptraps restart');
-				exec('/etc/init.d/S43provisioning cron_setup');
+				Helper::exec(0, '/usr/local/init/S90systemlog stop');
+				Helper::exec(0, '/usr/local/init/S81snmptraps stop');
+				Helper::exec(0, '/usr/local/init/S80snmpd stop');
+				Helper::exec(0, '/usr/local/init/S50isgw stop', $ausgabe);
+				Helper::exec(0, '/usr/local/init/S03acl stop');
+				
+				Helper::exec(0, '/usr/local/init/S03acl start');
+				Helper::exec(0, '/usr/local/init/S50isgw start', $ausgabe);
+				Helper::exec(0, '/usr/local/init/S80snmpd start');
+				Helper::exec(0, '/usr/local/init/S81snmptraps start');
+				Helper::exec(0, '/usr/local/init/S90systemlog start');
+				
+				Helper::exec(0, '/etc/init.d/S45provisioning cron_setup');
+				Helper::exec(0, '/etc/init.d/S65cloud restart'); 
 			}
 			else if ($option == 1) {
 				require_once "/usr/local/www/berogui/includes/isgwtelnet.php";
@@ -1052,37 +1123,15 @@ class fileManagement {
 				$isgw->reload();
 	
 				if ($this->ba->get('acl_reload') == 1) {
-					exec('/usr/local/init/S03acl restart');
+					Helper::exec(0, '/usr/local/init/S03acl restart');
 					$this->ba->set('acl_reload', 0);
 				}
-				exec('/usr/local/init/S60cloud restart');
-				exec('/etc/init.d/S43provisioning cron_setup');
-				exec('/etc/init.d/S91userapp apply');
+				Helper::exec(0, '/etc/init.d/S45provisioning cron_setup');
+				Helper::exec(0, '/etc/init.d/S65cloud restart'); 
+				Helper::exec(0, '/etc/init.d/S91userapp apply');
 			}
 		}
 
-		## check the ACL rules: if a port is open from anywhere, we update beroconf
-		## to display a warning message
-		$ports_opened = array();
-		foreach (explode("\n", file_get_contents("{$this->conf_folder}/network.acl")) as $acl) {
-			if (preg_match('/INPUT;(tcp|udp|)?;(.*);.*\/0;ACCEPT;/', $acl, $matched)) {
-				$ports_opened[] = $matched[2];
-				unset($matched);
-			}
-		}
-		if (($key = array_search('65001', $ports_opened)) !== false) {
-			    unset($ports_opened[$key]);
-		}
-		if (empty($ports_opened)) {
-			foreach(array('fw-opened', 'fw-opened-ports') as $key) {
-				$this->bc->delete('root', $key);
-			}
-		}
-		else {
-			$this->bc->set('root', 'fw-opened', 'WARNING_MESSAGE_FW_RULES_OPENED');
-			$this->bc->set('root', 'fw-opened-ports', implode(':', $ports_opened));
-		}
-
 		if (!$this->ba->is_error()) {
 			$this->ba->set('activate', '0');
 		}
