@@ -7,6 +7,9 @@
 if (!class_exists('Helper')) {
 	require_once('/usr/local/www/berogui/includes/Helper/Helper.php');
 }
+if (!class_exists('HelperHtml')) {
+	require_once('/usr/local/www/berogui/includes/Helper/HelperHtml.php');
+}
 
 $hostname = file_exists('/etc/hostname') ? file_get_contents("/etc/hostname") : file_get_contents('/etc/hostname.default');
 
@@ -47,6 +50,9 @@ else {
 
 require_once("./includes/lang.php");
 require_once("./includes/Helper/Helper.php");
+
+$header_settings['gui-title'] = strlen($ba->get('device_name')) ? $ba->get('device_name') : constant($header_settings['gui-title']);
+
 ?>
 <html lang="en">
     <head>
@@ -214,7 +220,6 @@ require_once("./includes/Helper/Helper.php");
 
             //Anzeige der verschiedene "activate" knöpfe
             function aktivieren(aktiv, m, option, text) {
-
                 if (aktiv == 1 && activated == false) {
                     if (option == 2) {
                         document.getElementById('aktiv').innerHTML = '<input type=\'button\' id=\'aktivieren\' class=\'aktivieren2\' value=\'' + text + '\'>';
@@ -322,13 +327,12 @@ require_once("./includes/Helper/Helper.php");
 			});
 		}
 		</script>
-		<title><?php echo constant($header_settings['gui-title']); echo strlen($hostname)>0?" - ".$hostname:""; ?></title>
+		<title><?php echo $header_settings['gui-title']; echo strlen($hostname)>0?" - ".$hostname:""; ?></title>
 		<?php	
 		$beroConf = new beroConf('root');
-		$is_cloud_status_show = ($ba->get('cloud_show_status') == 1);
-    		$is_cloud_enable = ($beroConf->get('root','cloud_enable'));
-    		$cloud_key = $beroConf->get("root", "cloud_key");
-    		$ba_error = $ba->get('error');
+		$is_cloud_status_show = ($beroConf->get('root', 'cloud_show_status') == 1);
+		$is_cloud_enable = ($beroConf->get('root','cloud_enable'));
+		$cloud_key = $beroConf->get("root", "cloud_key");
 		
 		$show_notif = $is_sbc_vm ? $beroConf->get('root', 'sbcvmupdate-shownotif') : true;
 
@@ -340,10 +344,16 @@ require_once("./includes/Helper/Helper.php");
 		} 
 
 		$warning = '';
-		foreach (array('rootfs-notenough-space', 'new-gui-password', 'fw-opened', 'sshtunnel-fromproxy-failed', 'sshtunnel-toproxy-failed', 'sbcvm-invalid-subscription', 'rootfs-phpcgi-failed', 'rootfs-phpcgi-success') as $key) {
+
+		foreach (array(
+			'appfs-update-failed', 'userapps-notenough-space', 'tmp-notenough-space', 'new-gui-password', 'fw-opened',
+			'sshtunnel-fromproxy-failed', 'sshtunnel-toproxy-failed', 'sbcvm-invalid-subscription',
+			'rootfs-phpcgi-failed', 'rootfs-phpcgi-success', 'TLSv1.2-disabled',
+		) as $key) {
 			$warning .= Helper::headerMessage($key, $beroConf);
 		}
 		unset($beroConf);
+		$warning .= Helper::checkRootfsPackages();
 
 		$option = $ba->get("activate");
 
@@ -445,7 +455,7 @@ require_once("./includes/Helper/Helper.php");
 								if (data == 0) {
 									if ($(aktivierenThis).prop("class") == 'aktivieren3') {
 										var message = 'This action will reboot the system.';
-										showDialog(targetUrl, message, 'Activate your settings ?');
+										showDialog(targetUrl, message, 'Activate your settings?');
 									}
 									else {
 										$(aktivierenThis).prop("disabled", true);
@@ -479,7 +489,7 @@ require_once("./includes/Helper/Helper.php");
 										message = message + "<?php echo WARNING_GRACEFUL_DIALOG_MESSAGE_RED; ?>";
 									}
 									
-									showDialog(targetUrl, message, 'Activate your settings ?', 'activate');
+									showDialog(targetUrl, message, 'Activate your settings?', 'activate');
 								}
 							},
 						});
@@ -564,7 +574,7 @@ require_once("./includes/Helper/Helper.php");
         
     $ret .= "<div class=\"part2\">";
     if ($is_cloud_status_show && !$is_sbc_vm) {
-        if ($is_cloud_enable == 1 && empty($cloud_key) == false && $ba_error == '' ) {
+        if ($is_cloud_enable == 1 && empty($cloud_key) == false) {
             $ret .= "<a id='cloud_status' class='part2' href='index.php?m=BeroCloud' data-toggle='tooltip' data-placement='top' title='" . BEROCLOUD_STATUS_SUCCESS_DIS . "'>
                      <span style='color:black'>beroCloud: </span><img style='vertical-align: text-top' src='./includes/images/punkt_gruen.gif'></a>";
 
@@ -607,7 +617,7 @@ require_once("./includes/Helper/Helper.php");
 			. "</div>";
 	}
 
-	$ret .= $warning.$firmware_update.$reboot_required;
+	$ret .= $firmware_update.$reboot_required.$warning;
 	
 		if ($showSecurityMessage) {
 		$ret .= "
@@ -615,10 +625,67 @@ require_once("./includes/Helper/Helper.php");
     <div id='security_mess' class='text-center' style='margin-top:5px; color:red;'>" . SECURITY_CHANGE_PASSWORD_MESSAGE_DIS . "</div>";
 	}
 
-	if (file_exists('/tmp/error_certificate.log'))
-	{
-		$ret .= "
-	<br/>
-	<div id='error_certificate' class='text-center' style='margin-top:5px; color:red;'>". ERROR_HTTPS_CERTIFICATE_MESSAGE_DIS . "</div>";
+	if (file_exists('/tmp/error_certificate.log')) {
+		$ret .= "<br/><div id='error_certificate' class='text-center' style='margin-top:5px; color:red;'>". ERROR_HTTPS_CERTIFICATE_MESSAGE_DIS . "</div>";
 	}
-	?>
+
+	// display isgw errors
+	require_once("./includes/isgwtelnet.php");
+	$isgw = new isgwtelnet();
+	$isgwLogin = $isgw->isgw_login();
+	if (file_exists('/var/log/isgw.err'))$isgwErrLog =@file('/var/log/isgw.err');
+	else if($isgwLogin == false) $ret .= "<br/><div id='isgw_error' class='text-center' style='margin-top:5px; color:red;'>". WARNING_MESSAGE_ISGW_STOPPED . "</div>";
+
+	while($isgwLogin==false && file_exists('/var/log/isgw.err')){
+		if (@file_get_contents('/proc/uptime')>90){
+			//go over the last 26 lines of the isgw.err log, and check for any errors
+			foreach($isgwErrLog =array_slice($isgwErrLog,-26) as $key => $line){
+				switch($line){
+					case strstr($line,'ISGW EXITCODE '):
+						$error = explode(': ',$line);
+						$ret .= "<br/><div id='isgw_error' class='text-center' style='margin-top:5px; color:red;'>".WARNING_MESSAGE_ISGW_INCLUDE_ERR."<br>".$error[1]. "</div>";
+						break(3);
+
+					case"isgw: not starting, missing config file.\n":
+						$ret .= "<br/><div id='isgw_error' class='text-center' style='margin-top:5px; color:red;'>". WARNING_MESSAGE_ISGW_CONF_MISSING. "</div>";
+						break(3);
+
+					default :
+						continue(2);
+				}
+			}
+			//couldn't find error in isgw.err log
+			$ret .= "<br/><div id='isgw_error' class='text-center' style='margin-top:5px; color:red;'>". WARNING_MESSAGE_ISGW_STOPPED . "</div>";
+			break;
+		}
+		else{
+			$ret .= "<br/><div id='isgw_error' class='text-center' style='margin-top:5px; color:red;'>". STATE_ISWG_ERROR_DIS . "</div><br>";?>
+			<script type="text/javascript">
+						var intervalI =0;
+						var interval =setInterval( function(){
+							$.ajax({
+								url: "./modules/Telnet/isgw_request.php",
+								done: function(data){
+									if(data.responseText!='Error: login to ISGW'){
+										$('#isgw_error').remove();
+										clearInterval(interval);
+									}
+								},
+							})
+							intervalI++;
+							if(intervalI>6){
+								$('#isgw_error').html(" <?php echo(WARNING_MESSAGE_ISGW_STOPPED) ?> ");
+								clearInterval(interval);
+							}
+						},10000);
+					</script>';
+					<?php
+			break;
+		}
+	}
+	if (is_string($isgwLogin)&& strncmp($isgwLogin, "wretsberoNet VoIP Gateway", 25) !== 0) {
+		$ret .=	"<div id='isgw_error' class='text-center' style='margin-top:5px; color:red;'>".WARNING_MESSAGE_ISGW_UNREACHABLE."</div>";
+	}
+	unset($isgwErrLog, $isgwLogin);
+ 
+?>
