@@ -475,6 +475,21 @@ echo $javascript;
 							<div> <?php echo from_pstn_src_setting($ba, 'analog'); ?></div>
 						</div>
 					</div>
+					
+					<div class='form-group group <?php echo $simple_class; ?>' data-toggle='tooltip' title='<?php echo ANALOG_FXS_WINK_OFFSET_INFO; ?>'>
+						<label for='fxs_wink_offset' class='col-sm-3 control-label'><?php echo ANALOG_FXS_WINK_OFFSET_LABEL; ?></label>
+						<div class='col-sm-8'>
+							<div> <?php echo HelperPstn::textfield($ba, $_GET['gr'], 'fxs_wink_offset', 'analog', '0'); ?></div>
+						</div>
+					</div>
+					
+					<div class='form-group group <?php echo $simple_class; ?>' data-toggle='tooltip' title='<?php echo ANALOG_FXS_WINK_DURATION_INFO; ?>'>
+						<label for='fxs_wink_duration' class='col-sm-3 control-label'><?php echo ANALOG_FXS_WINK_DURATION_LABEL; ?></label>
+						<div class='col-sm-8'>
+							<div> <?php echo HelperPstn::textfield($ba, $_GET['gr'], 'fxs_wink_duration', 'analog', '0'); ?></div>
+						</div>
+					</div>
+					
 					<?php
 				}
 				?>
