@@ -28,23 +28,23 @@ class BeroCloud {
 			unset($post['m'], $post['fixChrome'], $post['dummy']);
 
 			$list_post = array(	// GENERAL
-						'submit' => 'select',
-						// CLOUD
-						'cloud_username' => 'config-option', 'cloud_password' => 'password', 'deregister' => 'bool', 'cloud_enable' => 'bool', 'cloudAddress' => 'hostname',
-						'cloud_show_status' => 'bool','redirect_cfg' => 'bool',
-						// KEY
-						'supportKey' => 'str-length', 'supportPermanent' => 'bool', 'disconnect_submit' => 'select',
-						// PROXY
-						'proxyEnabled' => 'bool', 'proxyAddress' => 'hostname', 'proxyPort' => 'int-range', 'proxyType' => 'select', 'proxyUser' => 'config-option', 'proxySecret' => 'password',
-					  );
+				'submit' => 'select',
+				// CLOUD
+				'cloud_username' => 'config-option', 'cloud_password' => 'password', 'deregister' => 'bool', 'cloud_enable' => 'bool', 'cloudAddress' => 'hostname',
+				'cloud_show_status' => 'bool','redirect_cfg' => 'bool',
+				// KEY
+				'supportKey' => 'str-length', 'supportPermanent' => 'bool', 'disconnect_submit' => 'select',
+				// PROXY
+				'proxyEnabled' => 'bool', 'proxyAddress' => 'hostname', 'proxyPort' => 'int-range', 'proxyType' => 'select', 'proxyUser' => 'config-option', 'proxySecret' => 'password',
+			);
 		
 			$list_post_options = array(	
-							'submit'    => array('Register', 'Registrieren', 'Save', 'Speichern', 'Connect', 'Verbinden','Deregister','Deregistrieren')	, // impossible to generalize with BUTTON_***** without reworking the class
-							'disconnect_submit' => array('Disconnect', 'Trennen')		, // impossible to generalize with CLOUD_SUPPORT_DISCONNECT_BUTTON_DIS without reworking the class (and all classes)
-							'proxyPort' => array('min' => 1, 'max' => 65535)		,
-							'proxyType' => array('CURLPROXY_HTTP', 'CURLPROXY_SOCKS5')	,
-							'supportKey'=> array('min' => 8, 'max' => 8)
-						  );
+				'submit'    => array('Register', 'Registrieren', 'Save', 'Speichern', 'Connect', 'Verbinden','Deregister','Deregistrieren')	, // impossible to generalize with BUTTON_***** without reworking the class
+				'disconnect_submit' => array('Disconnect', 'Trennen')		, // impossible to generalize with CLOUD_SUPPORT_DISCONNECT_BUTTON_DIS without reworking the class (and all classes)
+				'proxyPort' => array('min' => 1, 'max' => 65535)		,
+				'proxyType' => array('CURLPROXY_HTTP', 'CURLPROXY_SOCKS5')	,
+				'supportKey'=> array('min' => 8, 'max' => 8)
+		  );
 
 			$this->post_checked = 1;
 			$this->post_attr = Helper::sanitizePost($post, $list_post, $this->post_checked, $this->reasonRejected, $list_post_options);
@@ -56,12 +56,12 @@ class BeroCloud {
 	/*
 	 * @return string HTML code
 	 */
-	function _display_tabs ($bc, $ba, $simple_class) {
+	function _display_tabs($bc, $simple_class) {
 		$tabs = '';
 		$display_tabs = '';
 		if (strlen($simple_class) == 0) {
 			$tabs =	"\t\t".'<li><a href="#tabs-3">'. CLOUD_PROXY_SETTINGS .'</a></li>' . "\n";
-			$display_tabs =	$this -> _display_tab3($ba) . "\n";
+			$display_tabs =	$this -> _display_tab3($bc) . "\n";
 		}
 
 		$html_str = '<br/>' . "\n" . '<br/>' . "\n" .
@@ -78,8 +78,8 @@ class BeroCloud {
 								$tabs .
 								"\t".'</ul>' . "\n\n" .
 
-								$this -> _display_tab1($bc, $ba) . "\n" .
-								$this -> _display_tab2($ba) . "\n" .
+								$this -> _display_tab1($bc) . "\n" .
+								$this -> _display_tab2($bc) . "\n" .
 								$display_tabs . 
 
 								"\n\n" . '<!-- END TABS //-->' . "\n" .
@@ -91,14 +91,14 @@ class BeroCloud {
 	/*
 	 * @return string HTML code
 	 */
-	function _display_tab1 ($bc, $ba)
+	function _display_tab1($bc)
 	{
 		$html_str = "\n\n" . '<!-- BEGIN TAB1 //-->' . "\n\n" .
 								'<div id="tabs-1" style="margin-top: 20px;">' . "\n";
 
 		$html_str .= 	$this->cloudRegisterTable($bc) . "\n";
 		$html_str .= 	"<br><br>" . "\n";
-		$html_str .= 	$this->cloudTable($bc, $ba) . "\n";
+		$html_str .= 	$this->cloudTable($bc) . "\n";
 
 		$html_str .=	'</div>' . "\n";
 
@@ -108,12 +108,12 @@ class BeroCloud {
 	/*
 	 * @return string HTML code
 	 */
-	function _display_tab2 ($ba) 
+	function _display_tab2($bc) 
 	{
 		$html_str = "\n\n" . '<!-- BEGIN TAB2 //-->' . "\n\n" .
 								'<div id="tabs-2" style="margin-top: 20px;">' . "\n";
 
-		$html_str .= $this->cloudSupportKey($ba) . "\n";
+		$html_str .= $this->cloudSupportKey($bc) . "\n";
 
 		$html_str .= '</div>' . "\n";
 
@@ -123,12 +123,12 @@ class BeroCloud {
 	/*
 	 * @return string HTML code
 	 */
-	function _display_tab3 ($ba)
+	function _display_tab3 ($bc)
 	{
 		$html_str = "\n\n" . '<!-- BEGIN TAB3 //-->' . "\n\n" .
 								'<div id="tabs-3" style="margin-top: 20px;">' . "\n";
 
-		$html_str .= $this->cloudProxyTable($ba) . "\n";
+		$html_str .= $this->cloudProxyTable($bc) . "\n";
 
 		$html_str .= '</div>' . "\n";
 
@@ -147,7 +147,7 @@ class BeroCloud {
 		$ba = new beroAri();
 		require_once("./includes/lang.php");
 
-		require_once( '/usr/fallback/beroConf.php' );
+		require_once('/usr/fallback/beroConf.php');
 		$bc = new beroConf('root');
 
 		// check gateway and nameserver settings
@@ -159,10 +159,13 @@ class BeroCloud {
 				break;
 			}
 		}
-		foreach (Helper::getNetworkNameserver() as $nameserver) {
-			if (strlen($nameserver) > 0) {
-				$this->_hasNameserver = true;
-				break;
+		$nameservers = Helper::getNetworkNameserver();
+		if (!empty($nameservers)) {
+			foreach ($nameservers as $nameserver) {
+				if (strlen($nameserver) > 0) {
+					$this->_hasNameserver = true;
+					break;
+				}
 			}
 		}
 
@@ -177,7 +180,7 @@ class BeroCloud {
 			$ret .= Helper::displayErrorMessage($this->reasonRejected['request'], $this->reasonRejected['checkor'], $this->reasonRejected['key']);
 		}
 
-		$ret .= $this -> _display_tabs($bc, $ba, $simple_class);
+		$ret .= $this -> _display_tabs($bc, $simple_class);
 		$ret .= $this -> javascript();
 
 		return $ret;
@@ -186,8 +189,8 @@ class BeroCloud {
 	/**
 	 * @return string Checkbox cloud show status
 	 */
-	function cloud_show_status($ba) {
-		$cloud_show = $ba->get("cloud_show_status");
+	function cloud_show_status($bc) {
+		$cloud_show = $bc->get('root', "cloud_show_status");
 		$checked = ($cloud_show == "1") ? "checked" : "";
 		ob_start();
 		?>
@@ -228,8 +231,8 @@ class BeroCloud {
 	/**
 	 * @return string Textfeld Cloud Adresse
 	 */
-	function cloud_url($bc, $ba) {
-		$cloudAddress = $ba->get("cloudAddress");
+	function cloud_url($bc) {
+		$cloudAddress = $bc->get('root', "cloudAddress");
 		$cloudkey = $bc->get("root", "cloud_key");
 		
 		$warning = "onclick='return checkCloudAddress();'";
@@ -263,8 +266,8 @@ class BeroCloud {
 	/**
 	 * @return string Checkbox cloud proxy enable
 	 */
-	function proxy_enable($ba) {
-		$proxy_enable = $ba->get("proxyEnabled");
+	function proxy_enable($bc) {
+		$proxy_enable = $bc->get('root', "proxyEnabled");
 		$checked = ($proxy_enable == "1") ? "checked" : "";
 		ob_start();
 		?>
@@ -278,8 +281,8 @@ class BeroCloud {
 	 * 
 	 * @return string Dropdown cloud proxy type
 	 */
-	function proxy_type($ba) {
-		$proxyType = $ba->get("proxyType");
+	function proxy_type($bc) {
+		$proxyType = $bc->get('root', "proxyType");
 		$selectedHttp = ($proxyType == "CURLPROXY_HTTP") ? "selected" : "";
 		$selectedSocks5 = ($proxyType == "CURLPROXY_SOCKS5") ? "selected" : "";
 		ob_start();
@@ -437,9 +440,9 @@ class BeroCloud {
 	/**
 	 * @return string HTML code
 	 */
-	function cloudSupportKey ($ba)
+	function cloudSupportKey($bc)
 	{
-		$permanent_remote_support_active = $ba->get("permanent_remote_support_active");
+		$permanent_remote_support_active = $bc->get('root', "permanent_remote_support_active");
 		$checked = ($permanent_remote_support_active == "1") ? "checked" : "";
 		
 		ob_start();
@@ -493,14 +496,14 @@ class BeroCloud {
 	/**
 	 * @return string HTML form for the general cloud settings
 	 */
-	function cloudTable($bc, $ba) {
+	function cloudTable($bc) {
 		ob_start();
 		?>
 		<form name='cloud' id='cloud' action='' class="form-horizontal" method='POST'>
 			<div class="form-group">
 				<label for='cloud_show_status' class='col-sm-5 control-label'><?php echo BEROCLOUD_SHOW_STATUS ?></label>
 				<div class='col-sm-4 form-checkbox'>
-					<?php echo $this->cloud_show_status($ba) ?>
+					<?php echo $this->cloud_show_status($bc) ?>
 				</div>
 			</div>
 			<div class="form-group">
@@ -518,7 +521,7 @@ class BeroCloud {
 			<div class="form-group">
 				<label for='cloudAddress' class='col-sm-5 control-label'><?php echo CLOUD_URL_DIS ?></label>
 				<div class='col-sm-4'>
-					<?php echo $this->cloud_url($bc, $ba) ?>
+					<?php echo $this->cloud_url($bc) ?>
 				</div>
 			</div>
 		</form>
@@ -527,10 +530,9 @@ class BeroCloud {
 	}
 
 	/**
-	 * @param beroAri $ba
 	 * @return string HTML form für the cloud proxy settings
 	 */
-	function cloudProxyTable($ba) {
+	function cloudProxyTable($bc) {
 		ob_start();
 		?>
 		<form name='proxy' id='proxy' action='' class="form-horizontal" method='POST'>
@@ -538,37 +540,37 @@ class BeroCloud {
 			<div class="form-group">
 				<label for='proxyEnabled' class='col-sm-5 control-label'><?php echo CLOUD_PROXY_ENABLE ?></label>
 				<div class='col-sm-4 form-checkbox'>
-					<?php echo $this->proxy_enable($ba) ?>
+					<?php echo $this->proxy_enable($bc) ?>
 				</div>
 			</div>
 			<div class="form-group">
 				<label for='proxyAddress' class='col-sm-5 control-label'><?php echo CLOUD_PROXY_ADDRESS ?></label>
 				<div class='col-sm-4'>
-					<input type='text' class='form-control input-sm' name='proxyAddress' value='<?php echo $ba->get('proxyAddress') ?>'>
+					<input type='text' class='form-control input-sm' name='proxyAddress' value='<?php echo $bc->get('root', 'proxyAddress') ?>'>
 				</div>
 			</div>
 			<div class="form-group">
 				<label for='proxyPort' class='col-sm-5 control-label'><?php echo CLOUD_PROXY_PORT ?></label>
 				<div class='col-sm-4'>
-					<input type='text' class='form-control input-sm' name='proxyPort' value='<?php echo $ba->get('proxyPort') ?>'>
+					<input type='text' class='form-control input-sm' name='proxyPort' value='<?php echo $bc->get('root', 'proxyPort') ?>'>
 				</div>
 			</div>
 			<div class="form-group">
 				<label for='proxyType' class='col-sm-5 control-label'><?php echo CLOUD_PROXY_TYPE ?></label>
 				<div class='col-sm-4'>
-					<?php echo $this->proxy_type($ba) ?>
+					<?php echo $this->proxy_type($bc) ?>
 				</div>
 			</div>
 			<div class="form-group">
 				<label for='proxyUser' class='col-sm-5 control-label'><?php echo CLOUD_PROXY_USER ?></label>
 				<div class='col-sm-4'>
-					<input type='text' class='form-control input-sm' name='proxyUser' value='<?php echo $ba->get('proxyUser') ?>'>
+					<input type='text' class='form-control input-sm' name='proxyUser' value='<?php echo $bc->get('root', 'proxyUser') ?>'>
 				</div>
 			</div>
 			<div class="form-group">
 				<label for='proxySecret' class='col-sm-5 control-label'><?php echo CLOUD_PROXY_SECRET ?></label>
 				<div class='col-sm-4'>
-					<input type='password' class='form-control input-sm' name='proxySecret' id='proxy-secret' onchange="$('#password-dummy').val('1');" value='<?php echo strlen($ba->get('proxySecret')) === 0 ? '' : '*****'; ?>'>
+					<input type='password' class='form-control input-sm' name='proxySecret' id='proxy-secret' onchange="$('#password-dummy').val('1');" value='<?php echo strlen($bc->get('root', 'proxySecret')) === 0 ? '' : '*****'; ?>'>
 				</div>
 			</div>
 			<div class="text-center">
@@ -580,18 +582,20 @@ class BeroCloud {
 		return ob_get_clean();
 	}
 
-	function cloud_deregister($cloud) {
-		return $cloud->send('deregister');	
-	}
-
 	/**
 	 * Saves the setting in the database
-	 * @param beroAri $ba
 	 * @return string HTML code
 	 */
 	function save($bc, $ba) {
-		require_once('/usr/local/php/include/berocloud/SbcApi.php');
-		$cloud = new SbcApi($bc, $ba);
+		$cloud = null;
+		if (file_exists('/usr/php/include/SbcApi.php')) {
+			require_once('/usr/php/include/SbcApi.php');
+			$cloud = new SbcApi($bc);
+		}
+		else if (file_exists('/usr/local/php/include/cloudApi.Class.php')) {
+			require_once('/usr/local/php/include/cloudApi.Class.php');
+			$cloud = new cloudApi();
+		}
 
 		$result = "";
 		//we now explicitly have to click the register button to register, only register is performed, no other post stuff will be evaluated
@@ -600,15 +604,21 @@ class BeroCloud {
 		 		return;
 		 	}
 
-			if (!$this->_hasGateway || !$this->_hasNameserver)
+			if (!$this->_hasGateway || !$this->_hasNameserver) {
 				$result = CLOUD_NETWORK_HINT;
-			else if (!$this->isDomainAvailable($ba->get("cloudAddress")))
+			}
+			else if (!$this->isDomainAvailable($bc->get('root', "cloudAddress")))
 				$result = CLOUD_NO_CONNECTION_HINT;
-			else {
-				$result = $cloud->send('register', array('cloud_username' => $this->post_attr['cloud_username'], 'cloud_password' => $this->post_attr['cloud_password']), array(), $info);
+			else if (!is_null($cloud)) {
+				$result = $cloud->send('register', $this->post_attr, array(), $info);
 				if ($result == false) {
-					$error = $cloud->getError();
-					$result = "{$error['msg']} | HTTP Status Code = {$error['code']}";
+					$error = method_exists($cloud, 'getError') ? $cloud->getError() : array('msg' => '<font color="#9900FF">Please check if system time has been configured correctly.</font><br>Otherwise device might already be registered. Please contact beroNet support', 'code' => 500);
+					if (strpos(trim($error['msg']), 'verify that the CA cert is OK')) {
+						$result = "SSL certificate problem, verify that the CA cert is OK or the time is correctly set | HTTP Status Code = {$error['code']}";
+					}
+					else {
+						$result = "{$error['msg']} | HTTP Status Code = {$error['code']}";
+					}
 				}
 				else {
 					preg_match("/[^a-zA-Z0-9=]*?yaqwsx(?<key>.+)yaqwsx/", $result, $key);
@@ -616,7 +626,7 @@ class BeroCloud {
 					if (isset($key['key'])) {
 						$bc->set('root', 'cloud_key', $key['key']);
 						$bc->set('root', 'cloud_enable', 1);
-						$ba->set('cloud_show_status', 1);
+						$bc->set('root', 'cloud_show_status', 1);
 						$table .= Helper::activate(1, true, $this->m_attr, ACTIVATE);
 						$result = preg_replace("/[^a-zA-Z0-9=]*?yaqwsx(?<key>.+)yaqwsx/", ". ", $result);
 					}
@@ -632,8 +642,7 @@ class BeroCloud {
 		//we now explicitly have to click the deregister button to register, only deregister is performed, no other post stuff will be evaluated
 		if (isset($this->post_attr['submit']) && $this->post_attr['submit'] == BUTTON_DEREGISTER) {
 
-			$result = $this->cloud_deregister($cloud);
-
+			$result = $cloud->send('deregister');
 			$bc->set('root', 'cloud_enable', 0);
 			$bc->set('root', 'cloud_key', '');
 			$table .= Helper::activate(1, true, $this->m_attr, ACTIVATE);
@@ -649,15 +658,14 @@ class BeroCloud {
 		
 		if (isset($this->post_attr['cloud_enable'])) {
 			
-			$oldAddress = $ba->get('cloudAddress');
+			$oldAddress = $bc->get('root', 'cloudAddress');
 			$cloudkey = $bc->get("root", "cloud_key");
 			
 			//cloud address changed, try to deregister first and reset cloudKey in any case
 			if (strcmp ($oldAddress, sqlite_escape_string(trim($this->post_attr['cloudAddress']))) != 0) {
 
 				if (strlen ($cloudkey)) {
-					$result = $this->cloud_deregister($cloud);
-					
+					$result = $cloud->send('deregister');
 					$table .= Helper::activate(1, true, $this->m_attr, ACTIVATE);
 					
 					if ($result != "" && trim($result) == "Device was deregistered") {
@@ -669,43 +677,33 @@ class BeroCloud {
 				}
 				$bc->set('root', 'cloud_key', '');
 			}
-			
-			
-			$bc->set('root', 'cloud_enable', sqlite_escape_string($this->post_attr['cloud_enable']));
-			$bc->set('root', 'redirect_cfg', sqlite_escape_string($this->post_attr['redirect_cfg']));
-			$ba->set("cloudAddress", sqlite_escape_string(trim($this->post_attr['cloudAddress'])));
-			$ba->set('cloud_show_status', sqlite_escape_string(trim($this->post_attr['cloud_show_status'])));
+
+			foreach (array('cloud_enable', 'redirect_cfg', 'cloudAddress', 'cloud_show_status') as $key) {
+				$bc->set('root', $key, sqlite_escape_string($this->post_attr[$key]));
+			}
 
 			if (isset($this->post_attr['cloud_key'])) {
 				$bc->set('root', 'cloud_key', sqlite_escape_string($this->post_attr['cloud_key']));
 			}
 
-
 			$table .= Helper::activate(1, true, $this->m_attr, ACTIVATE);
 			return $table;
 		}
 		
 		if ($this->post_attr['proxyEnabled'] == '1' && isset($this->post_attr['proxyAddress']) && isset($this->post_attr['proxyPort']) && isset($this->post_attr['proxyType'])) {
-			$ba->set('proxyEnabled', sqlite_escape_string($this->post_attr['proxyEnabled']));
-			$ba->set('proxyAddress', sqlite_escape_string($this->post_attr['proxyAddress']));
-			$ba->set('proxyPort', sqlite_escape_string($this->post_attr['proxyPort']));
-			$ba->set('proxyType', sqlite_escape_string($this->post_attr['proxyType']));
-			$ba->set('proxyUser', sqlite_escape_string($this->post_attr['proxyUser']));
+			foreach (array('Enabled', 'Address', 'Port', 'Type', 'User') as $key) {
+				$bc->set('root', "proxy{$key}", sqlite_escape_string($this->post_attr["proxy{$key}"]));
+			}
 			if (isset($this->post_attr['proxySecret'])) {
-				$ba->set('proxySecret', sqlite_escape_string($this->post_attr['proxySecret'])); // TODO: how to update the code to hash the password when a customer had already set a password ?
+				$bc->set('root', 'proxySecret', sqlite_escape_string($this->post_attr['proxySecret'])); // TODO: how to update the code to hash the password when a customer had already set a password ?
 			}
-			//$ba = new beroAri(); WHY DEFINE A NEW BEROARI ??
 			$table .= Helper::activate(1, true, $this->m_attr, ACTIVATE);
 			return $table;
 		}
 		else if ($this->post_attr['proxyEnabled'] == '0') {
-			$ba->set('proxyEnabled', 0);
-			$ba->set('proxyAddress', "");
-			$ba->set('proxyPort', "");
-			$ba->set('proxyType', "");
-			$ba->set('proxyUser', "");
-			$ba->set('proxySecret', "");
-			//$ba = new beroAri(); WHY DEFINE A NEW BEROARI ?
+			foreach (array('Enabled' => 0, 'Address' => '', 'Port' => '', 'Type' => '', 'User' => '', 'Secret' => '') as $key => $value) {
+				$bc->set('root', "proxy{$key}", $value);
+			}
 			$table .= Helper::activate(1, true, $this->m_attr, ACTIVATE);
 			return $table;
 		}
@@ -717,9 +715,9 @@ class BeroCloud {
 				exec ("kill -9 " . $output[0]);
 			}
 			
-			$ba->delete ("delete from key_val where key='permanent_remote_support_cmd'");
-			$ba->delete ("delete from key_val where key='permanent_remote_support_key'");
-			$ba->set ("permanent_remote_support_active", "0");
+			$bc->delete('root', 'permanent_remote_support_cmd');
+			$bc->delete('root', 'permanent_remote_support_key');
+			$bc->set('root', "permanent_remote_support_active", "0");
 			if (file_exists ("/usr/conf/remotesupport.conf")) {
 				unlink ("/usr/conf/remotesupport.conf");
 			}
@@ -730,11 +728,11 @@ class BeroCloud {
 		if (isset($this->post_attr['supportKey'])) {
 			if (!$this->_hasGateway || !$this->_hasNameserver) {
 				$table .= "<div class='text-center'><img src='./includes/images/punkt_rot.gif'><font color='red'>" . CLOUD_NETWORK_HINT . "</font><br/></div>";
-			} else if (!$this->isDomainAvailable($ba->get("cloudAddress"))) {
+			} else if (!$this->isDomainAvailable($bc->get('root', "cloudAddress"))) {
 				$table .= "<div class='text-center'><img src='./includes/images/punkt_rot.gif'><font color='red'>" . CLOUD_NO_CONNECTION_HINT . "</font><br/></div>";
 			} else {
 				
-				$result = $cloud->send('support-access', array(), array('get' => "key={$this->post_attr['supportKey']}"));
+				$result = $cloud->send('support-access', array('key' => $this->post_attr['supportKey']));
 				if ($result == false) {
 					$error = $cloud->getError();
 					$table.= "<div class='text-center'><img src='./includes/images/punkt_rot.gif'><font color='red'>{$error['msg']}</font><br/></div>";
@@ -749,9 +747,9 @@ class BeroCloud {
 						file_put_contents('/tmp/key', $result['sshKey']);
 						chmod('/tmp/key', 0600);
 						
-						$ba->set ("permanent_remote_support_active", "0");
-						$ba->set ("permanent_remote_support_key", $result['sshKey']);
-						$ba->set ("permanent_remote_support_cmd", $result['sysCmd']);
+						$bc->set('root', "permanent_remote_support_active", "0");
+						$bc->set('root', "permanent_remote_support_key", $result['sshKey']);
+						$bc->set('root', "permanent_remote_support_cmd", $result['sysCmd']);
 						
 						//kill any running instance
 						exec ("ps aux|grep ssh|grep StrictHostKeyChecking=no|grep -v grep|awk '{print $1}'|head -1", $output, $retval);
@@ -761,7 +759,7 @@ class BeroCloud {
 						exec('/sbin/' . $result['sysCmd']);
 						
 						if (isset($this->post_attr['supportPermanent'])) {
-							$ba->set ("permanent_remote_support_active", "1");
+							$bc->set('root', "permanent_remote_support_active", "1");
 							//since we don't do an activate, write the conf file here
 							file_put_contents("/usr/conf/remotesupport.conf", "SSHCMD:" . $result['sysCmd'] . "\n");
 							file_put_contents("/usr/conf/remotesupport.conf", $result['sshKey'] . "\n", FILE_APPEND);
