@@ -8,6 +8,10 @@
 include('/usr/local/www/berogui/includes/isgwtelnet.php');
 include_once('/usr/www/include/SQLite2ToSQLite3.php');
 
+function _isMatch($type, $regex) {
+	return(preg_match($regex, $type));
+}
+
 class PstnHardware {
 	
 	private		$m_attr,
@@ -21,7 +25,8 @@ class PstnHardware {
 	function __construct($m = '', $get = array(), $post = array(), $session = array()) {
 		$this->m_attr = $m;
 		$this->ltescan_attr = isset($get['ltescan']) ? Helper::sanitizeGet($get['ltescan'], 'int>0') : 0; 
-
+		$this->tdmreset_attr = isset($get['tdmreset']) ? Helper::sanitizeGet($get['tdmreset'], 'int>0') : 0;
+		
 		require_once('/usr/local/www/berogui/includes/Helper/HelperPstn.php');
 		$this->countries_list = HelperPstn::getCountriesList();
 
@@ -282,6 +287,15 @@ class PstnHardware {
 			print ('window.location = "index.php?m=PstnHardware"');
 			print ( '</script>">');
 		}
+		else if ($this->tdmreset_attr) {
+			ob_start();
+			include_once('/usr/local/php/tdmConfigure.php');
+			ob_end_clean();
+			echo "Resetting TDM Bus\n";
+			print ( '<script type="text/javascript">');
+			print ('window.location = "index.php?m=PstnHardware"');
+			print ( '</script>">');
+		}
 		else if ($this->isRequestRejected) {
 			$ret .= Helper::displayErrorMessage($this->reasonRejected['request'], $this->reasonRejected['checkor'], $this->reasonRejected['key']);
 		}
@@ -477,6 +491,9 @@ class PstnHardware {
 		$database = new beroAri();
 		require_once("./includes/lang.php");
 
+		if ($database->get('gui_mode') == 'simple')
+			$simple_class = 'simple';
+
 		$q = $database->select("SELECT distinct lif, type FROM cas order by lif");
 
 		//Änderung des Interface Types und Protocols wenn CAS gesteckt ist und keine keine Einstellungen vorgenommen wurden
@@ -548,14 +565,23 @@ class PstnHardware {
 			$master_options.='<option value="all" ' . $allmaster . '>ALL</option>';
 			$master_options.='<option value="pcm" ' . $pcmmaster . '>PCM</option>';
 
-
 			$form_elements.='<br/><br/>'
-				. '<table class="table table-striped table-bordered" style="width:90% !important; margin:auto;">'
-				. '<tr onmouseover=\'Tip("' . HARDWARE_MASTER . '")\' onmouseout="UnTip()"><th><div class="col-sm-2"><b>' . HARDWARE_MASTER_DIS . ':&nbsp;</b></div>'
-				. '<div class="col-sm-3"><select name="master" class="form-control" id="master" ' . $disabled . '>'
-				. $master_options
-				. '</select></div>'
-				. '</th></tr>'
+			. '<table class="table table-striped table-bordered" style="width:90% !important; margin:auto;">'
+			. '<tr><th>'
+			. '<div onmouseover=\'Tip("' . HARDWARE_MASTER . '")\' onmouseout="UnTip()" class="col-sm-2"><b>' . HARDWARE_MASTER_DIS . ':&nbsp;</b></div>'
+			. '<div onmouseover=\'Tip("' . HARDWARE_MASTER . '")\' onmouseout="UnTip()" class="col-sm-3"><select name="master" class="form-control" id="master" ' . $disabled . '>'
+			. $master_options
+			. '</select></div>';
+			
+			
+			$q = $database->select("select lif from lte where type='bf2LTE';");
+			if (sqlite_num_rows ($q) > 0) {
+					$form_elements.= '<div class="col-sm-2" onmouseover="Tip(\'Re-initializes the TDM bus\')" onmouseout="UnTip()">';
+					$form_elements.= "<button style='float: right;' type='button' onclick=\"location.href='index.php?m=PstnHardware&tdmreset=1';\">Reset TDM Bus</button>";
+					$form_elements.= '</div>';
+			}
+				
+			$form_elements.= '</th></tr>'
 				. '</table>';
 			//End Master setting
 
@@ -573,7 +599,7 @@ class PstnHardware {
 				}
 				$form_elements.="</div>";
 				//Clock - Synchonisation port
-				if (!in_array($ent['type'], array("bf4FXS", "bf8FXS", "bf4FXO", "bf2FXO", "bf1FXS", "bf2GSM", "bf2LTE"))) {
+				if (!in_array($ent['type'], array("bf4FXS", "bf8FXS", "bf4FXO", "bf2FXO", "bf1FXS", "bf2FXS", "bf2GSM", "bf2LTE"))) {
 					$form_elements.=$this->getClock($ent['lif'], $ent['type'], $database);
 				}
 				$form_elements.="</div></th></tr>";
@@ -618,19 +644,19 @@ class PstnHardware {
 								<input type=hidden name=type[] value='isdn'></td>";
 						}
 						if ($entry['lt'] == 1) {
-							$form_elements.="<td><b>" . HARDWARE_TERMINATION_DIS . ":</b>&nbsp;<input type='checkbox' name='lt" . $entry['port'] . "' checked value='1' onmouseover=\"Tip('" . ISDNHW_LT . "')\" onmouseout='UnTip()'></td>";
+							$form_elements.="<td class='$simple_class'><b>" . HARDWARE_TERMINATION_DIS . ":</b>&nbsp;<input type='checkbox' name='lt" . $entry['port'] . "' checked value='1' onmouseover=\"Tip('" . ISDNHW_LT . "')\" onmouseout='UnTip()'></td>";
 						} else {
-							$form_elements.="<td><b>" . HARDWARE_TERMINATION_DIS . ":</b>&nbsp;<input type='checkbox' name='lt" . $entry['port'] . "' value='1' onmouseover=\"Tip('" . ISDNHW_LT . "')\" onmouseout='UnTip()'></td>";
+							$form_elements.="<td class='$simple_class'><b>" . HARDWARE_TERMINATION_DIS . ":</b>&nbsp;<input type='checkbox' name='lt" . $entry['port'] . "' value='1' onmouseover=\"Tip('" . ISDNHW_LT . "')\" onmouseout='UnTip()'></td>";
 						}
 						if ($entry['permanentl1'] == 1) {
-							$form_elements.="<td><b>" . HARDWARE_PERMANENTL1_DIS . ":</b>&nbsp;<input type='checkbox' name='permanentl1" . $entry['port'] . "' id='permanentl1" . $entry['port'] . "' checked value='1'><script>enablepl1_checkclock(\"" . $entry['port'] . "\",\"" . $ent['lif'] . "\"," . $li_ports_list . ");</script></td>";
+							$form_elements.="<td class='$simple_class'><b>" . HARDWARE_PERMANENTL1_DIS . ":</b>&nbsp;<input type='checkbox' name='permanentl1" . $entry['port'] . "' id='permanentl1" . $entry['port'] . "' checked value='1'><script>enablepl1_checkclock(\"" . $entry['port'] . "\",\"" . $ent['lif'] . "\"," . $li_ports_list . ");</script></td>";
 						} else {
-							$form_elements.="<td><b>" . HARDWARE_PERMANENTL1_DIS . ":</b>&nbsp;<input type='checkbox' name='permanentl1" . $entry['port'] . "' id='permanentl1" . $entry['port'] . "' value='1'><script>enablepl1_checkclock(\"" . $entry['port'] . "\",\"" . $ent['lif'] . "\"," . $li_ports_list . ");</script></td>";
+							$form_elements.="<td class='$simple_class'><b>" . HARDWARE_PERMANENTL1_DIS . ":</b>&nbsp;<input type='checkbox' name='permanentl1" . $entry['port'] . "' id='permanentl1" . $entry['port'] . "' value='1'><script>enablepl1_checkclock(\"" . $entry['port'] . "\",\"" . $ent['lif'] . "\"," . $li_ports_list . ");</script></td>";
 						}
 						
-						$form_elements.="<td><b>" . ISDNHW_CRLEN_NAME . ":</b>&nbsp;<input type='checkbox' name='crlen" . $entry['port'] . "' id='crlen" . $entry['port'] . "' "
+						$form_elements.="<td class='$simple_class'><b>" . ISDNHW_CRLEN_NAME . ":</b>&nbsp;<input type='checkbox' name='crlen" . $entry['port'] . "' id='crlen" . $entry['port'] . "' "
 						. ($entry['crlen'] == 2 ? "checked" : "") . " value='2' onmouseover=\"Tip('" . ISDNHW_CRLEN_TOOLTIP . "')\" onmouseout='UnTip()'></td>";
-						$form_elements.="<td><b>" . ISDNHW_CIDLEN_NAME . ":</b>&nbsp;<input type='checkbox' name='cidlen" . $entry['port'] . "' id='cidlen" . $entry['port'] . "' "
+						$form_elements.="<td class='$simple_class'><b>" . ISDNHW_CIDLEN_NAME . ":</b>&nbsp;<input type='checkbox' name='cidlen" . $entry['port'] . "' id='cidlen" . $entry['port'] . "' "
 						. ($entry['cidlen'] == 2 ? "checked" : "") . " value='2' onmouseover=\"Tip('" . ISDNHW_CIDLEN_TOOLTIP . "')\" onmouseout='UnTip()'></td>";
 						
 					}
@@ -665,7 +691,7 @@ class PstnHardware {
 				while ($entry = $database->fetch_array($query)) {
 					$form_elements.="<tr>"
 						. "<td><b>" . HARDWARE_PORT_DIS . ":</b>&nbsp;" . $entry['port'] . "&nbsp;</td>"
-						. "<td colspan='5'><b>" . HARDWARE_PORT_TYPE_DIS . ":</b>&nbsp;" . $entry['port_type'] 
+						. "<td colspan='7'><b>" . HARDWARE_PORT_TYPE_DIS . ":</b>&nbsp;" . $entry['port_type'] 
 						. "<input type=hidden name=id_upd[] value=" . $entry['port'] . "><input type=hidden name=type[] value='analog'></td>";
 				}
 				//GSM
@@ -701,7 +727,6 @@ class PstnHardware {
 						. "<td><b>" . $this->gsm_provider_settings($entry['port']) . "</b>&nbsp;" . "&nbsp;</td>";
 				}
 				
-				
 				//CAS
 				$query = $database->select("select * from cas where lif='" . $ent['lif'] . "'");
 				while ($entry = $database->fetch_array($query)) {
@@ -791,8 +816,7 @@ class PstnHardware {
 			$revision = Helper::getRevision();
 
 			//Country
-			$analog_modules = array("bf4FXO", "bf2FXO", "bf4FXS", "bf8FXS", "bf2S02FXS", "bf1FXS");
-			if (count(array_intersect($analog_modules, $type)) != 0) {
+			if (!empty($type) && count(array_filter(array_map('_isMatch', $type, array_fill(0, count($type), '/bf.*FX[SO]/')))) > 0) {
 				$form_elements.="<script>function country_setting(param)
 			{
                             if (param!='USER'){
@@ -820,8 +844,6 @@ class PstnHardware {
 				//FXO specific options
 				$country_modules = array("bf4FXO", "bf2FXO");
 				if (count(array_intersect($country_modules, $type)) != 0) {
-					if ($database->get('gui_mode') == 'simple')
-						$simple_class = 'simple';
 					$form_elements.="<tr ><th><b>" . HARDWARE_COUNTRY_DIS . ":</b></th><th><select class='form-control' name='country' class='country' onchange=\"country_setting($(this).val());\" onmouseover=\"Tip('" . HARDWARE_COUNTRY . "')\" onmouseout='UnTip()'>";
 					foreach ($this->countries_list as $value) {
 						if ($value == $database->get('country'))
@@ -931,8 +953,7 @@ class PstnHardware {
 					$form_elements.="<input type='text' class='form-control' name='wait4idle' value='" . $fxo_config_wait4idle . "'> </tr>\n";
 				}
 
-				$voltage_modules = array("bf4FXS", "bf8FXS", "bf2S02FXS", "bf1FXS");
-				if (count(array_intersect($voltage_modules, $type)) != 0) {
+				if (count(array_filter(array_map('_isMatch', $type, array_fill(0, count($type), '/bf.*FXS/')))) > 0) {
 					$form_elements.="<tr ><th><b style='vertical-align: middle;'>" . HARDWARE_BOOSTRINGER_DIS . ":</b></th><th><select class='form-control' name='boostringer'>";
 
 					($database->get('boostringer') == 0) ? $form_elements.="<option value='0' selected>49V</option>" : $form_elements.="<option value='0'>49V</option>";
